from __future__ import annotations

import random
import string
from typing import Dict, List, Optional, Generator, Any

from git import Repo

from checkov.secrets.git_types import Commit, CommitMetadata


def mock_set_repo(self) -> bool:
    self.repo = True
    return True


def mock_get_first_empty_commit(self, a) -> Commit:
    return Commit(
        metadata=CommitMetadata(
            commit_hash='c9b3268e15eb20fd406b9077a4c45875086d6c1b',
            committer='🏖first-empty-commiter',
            committed_datetime='2022-11-14T16:10:21+00:00'),
        files={
            '.gitignore': "--- ''\n+++ .gitignore\n@@ -0,0 +0,0 @@\n"}
    )


def mock_get_first_commit(self, a) -> Commit:
    commit_mock = \
        Commit(
            metadata=CommitMetadata(
                commit_hash='c9b3268e15eb20fd406b9077a4c45875086d6c1b',
                committer='🐲dragon of commits🐲',
                committed_datetime='2022-11-14T16:10:21+00:00'),
            files={
                '.gitignore': "--- ''\n+++ .gitignore\n@@ -0,0 +1,50 @@\n+# These are some examples of commonly ignored file patterns.\n+# You should customize this list as applicable to your project.\n+# Learn more about .gitignore:\n+#     https://www.atlassian.com/git/tutorials/saving-changes/gitignore\n+\n+# Node artifact files\n+node_modules/\n+dist/\n+\n+# Compiled Java class files\n+*.class\n+\n+# Compiled Python bytecode\n+*.py[cod]\n+\n+# Log files\n+*.log\n+\n+# Package files\n+*.jar\n+\n+# Maven\n+target/\n+dist/\n+\n+# JetBrains IDE\n+.idea/\n+\n+# Unit test reports\n+TEST*.xml\n+\n+# Generated by MacOS\n+.DS_Store\n+\n+# Generated by Windows\n+Thumbs.db\n+\n+# Applications\n+*.app\n+*.exe\n+*.war\n+\n+# Large media files\n+*.mp4\n+*.tiff\n+*.avi\n+*.flv\n+*.mov\n+*.wmv\n+\n",
                'readme_mock-first-commit-mock.txt': "--- ''\n+++ readme_mock-first-commit-mock.txt\n@@ -0,0 +1 @@\n+('https://developer.atlassian.com/server/jira/platform/oath/#generate-an-rsa-public-private-key-pair')\n\\ No newline at end of file\n",
                'test-multiline-secrets-first-commit-mock.json': '--- \'\'\n+++ test-multiline-secrets-first-commit-mock.json\n@@ -0,0 +1,18 @@\n+{\n+  "spec": [\n+    {\n+    "name": "TEST_PASSWORD_3",\n+    "value": "ABCPtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"\n+    },\n+    {\n+      "name": "SOME_NAME",\n+      "value": "some_value"\n+    },\n+    {\n+      "value": "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE",\n+      "value1": "1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35",\n+      "name": "TEST_PASSWORD_1",\n+      "name1": "TEST_PASSWORD_2"\n+    }\n+  ]\n+}\n\\ No newline at end of file\n'
            }
        )
    return commit_mock


def mock_git_repo_commits1(self, last_commit_sha: str) -> List[Commit]:
    """
        add secret (secret1 added) - +1
        move the secret to different line - 0
        modify the secret value (secret1 removed=update + secret2 added) - +1
        remove the secret (secret2 removed=update) - 0
        add file with new secret (secret3 added) - +1
    """
    commits_mock = [
        Commit(
            metadata=CommitMetadata(
                commit_hash='8a21fa691e17907afee57e93b7820c5943b12746',
                committer='Cherry🍒',
                committed_datetime='2022-12-14T16:10:21+00:00'),
            files={
                'Dockerfile': 'diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -4,6 +4,8 @@ FROM public.ecr.aws/lambda/python:3.9\n \n ENV PIP_ENV_VERSION="2022.1.8"\n \n+ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n+\n COPY Pipfile Pipfile.lock ./\n \n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='d3249f33376b94a939b67a638aba4557b071875f',
                committer='🍒Cherry🍒',
                committed_datetime='2022-12-14T16:28:47+00:00'),
            files={
                'Dockerfile': 'diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -1,10 +1,9 @@\n #checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n-\n+ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n ENV PIP_ENV_VERSION="2022.1.8"\n \n-ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n \n COPY Pipfile Pipfile.lock ./\n \n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='3d79bba03c6f0ddcfb8334f531701942c4be0f32',
                committer='Cherry🍒',
                committed_datetime='2022-12-14T16:32:13+00:00'),
            files={
                'Dockerfile': 'diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -1,7 +1,7 @@\n #checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n-ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n+ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n ENV PIP_ENV_VERSION="2022.1.8"\n \n \n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='7dff3b21fc2563f51655f34f0d3601cdf79d0d5e',
                committer='🍒Cherry🍒',
                committed_datetime='2022-12-14T16:54:05+00:00'),
            files={
                'Dockerfile': 'diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -1,7 +1,7 @@\n #checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n-ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n+\n ENV PIP_ENV_VERSION="2022.1.8"\n \n \n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='6941281550a12659bdbe87c9a537f88124f78fac',
                committer='🍒Cherry🍒',
                committed_datetime='2022-12-14T16:57:26+00:00'),
            files={
                'main.py': 'diff --git a/None b/main.py\nindex 0000..0000 0000\n--- a/None\n+++ b/main.py\n@@ -0,0 +1,4 @@\n+AWS_ACCESS_TOKEN="AKIAZZZZZZZZZZZZZZZZ"\n+\n+if __name__ == "__main__":\n+    print(AWS_ACCESS_TOKEN)\n\\ No newline at end of file\n'}
        ),
    ]
    return commits_mock


def mock_git_repo_commits2(self, last_commit_sha: str) -> List[Commit]:
    """
        add secret (secret1 added) - +1
        move the secret to different line - 0
        remove the secret (secret1 removed=update) - 0
        add secret (secret1 added - add the same secret - update) - 0
        move the secret to different line - 0
    """

    commits_mock = [
        Commit(
            metadata=CommitMetadata(
                commit_hash='11e59e4e578c6ebcb48aae1e5e078a54c62920eb',
                committer='Mango🥭',
                committed_datetime='2022-12-14T16:10:21+00:00'),
            files={
                'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -5,7 +5,7 @@ FROM public.ecr.aws/lambda/python:3.9\n \n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n-\n+ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n \n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='c7c932ef4d31c487a921d2ce8544a4a468adf6b9',
                committer='🥭Mango🥭',
                committed_datetime='2022-12-14T16:28:47+00:00'),
            files={
                'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -2,10 +2,10 @@\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n \n-\n+ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n-ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n+\n \n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='4b8321e46217a87e21240afd88cdc0f1a861c0f5',
                committer='Mango🥭',
                committed_datetime='2022-12-14T16:32:13+00:00'),
            files={
                'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -2,7 +2,6 @@\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n \n-ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n \n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='7bb5c69d95b31bc2242bcf08ce25e74e953f9ae9',
                committer='🥭Mango🥭',
                committed_datetime='2022-12-14T16:54:05+00:00'),
            files={
                'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -4,7 +4,7 @@ FROM public.ecr.aws/lambda/python:3.9\n \n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n-\n+ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n \n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='2675bffd2662aae7025b7f3bb5fd384cdab355b1',
                committer='🥭Mango🥭',
                committed_datetime='2022-12-14T16:57:26+00:00'),
            files={
                'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -1,10 +1,11 @@\n #checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n+ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n \n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n-ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n+\n \n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n'}
        ),
    ]
    return commits_mock


def mock_git_repo_commits3(self, last_commit_sha: str) -> List[Commit]:
    """
            add secret (secret1 added) - +1
            move the secret to different line - 0
            add secret equal to secret1 - +1
            remove one secret (secret1 - update add remove_commit_hash) - 0
        """
    commits_mock = [
        Commit(
            metadata=CommitMetadata(
                commit_hash='900b1e8f6f336a92e8f5fca3babca764e32c3b3d',
                committer='baguette🥖',
                committed_datetime='2022-12-14T16:10:21+00:00'),
            files={
                'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -1,6 +1,7 @@\n #checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n+ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n \n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='4229974aec78152c426b40db8b6912ba098f3add',
                committer='baguette🥖',
                committed_datetime='2022-12-14T16:28:47+00:00'),
            files={
                'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -1,11 +1,11 @@\n #checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n-ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n+\n \n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n-\n+ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n \n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='3c8cb7eedb3986308c96713fc65b006adcf3bc44',
                committer='baguette🥖',
                committed_datetime='2022-12-14T16:32:13+00:00'),
            files={
                'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -6,7 +6,7 @@ FROM public.ecr.aws/lambda/python:3.9\n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n-\n+ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n  && pipenv run pip install -r requirements.txt --target "${LAMBDA_TASK_ROOT}" \\\n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='697308e61171e33224757e620aaf67b1a877c99d',
                committer='baguette🥖',
                committed_datetime='2022-12-14T16:54:05+00:00'),
            files={
                'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -5,7 +5,7 @@ FROM public.ecr.aws/lambda/python:3.9\n \n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n-ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n+\n ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n'}
        ),
        Commit(  # this commit should make no difference - its just to have 5 commits returned from this mock
            metadata=CommitMetadata(
                commit_hash='697308e61171e332247z2i2bi0aaf67b1a877c99d',
                committer='baguette🥖',
                committed_datetime='2022-12-14T16:54:05+00:00'),
            files={
                'Dockerfile': 'diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -5,7 +5,7 @@ FROM public.ecr.aws/lambda/python:3.9\n \n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n-ENV AWS_PIPY="something"\n+\n ENV AWS_DIP="ELSE"\n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n'}
        ),
    ]
    return commits_mock


def mock_git_repo_commits_remove_file(self, last_commit_sha: str) -> List[Commit]:
    commits_mock = [
        Commit(
            metadata=CommitMetadata(
                commit_hash='63342dbee285973a37770bbb1ff4258a3184901e',
                committer='Lemon🍋',
                committed_datetime='2022-12-14T16:10:21+00:00'),
            files={
                'Dockerfile': 'diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -4,6 +4,7 @@ FROM public.ecr.aws/lambda/python:3.9\n \n ENV PIP_ENV_VERSION="2022.1.8"\n \n+ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n COPY Pipfile Pipfile.lock ./\n \n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='bca377900d08d442b1080893e50b8dc8276cfcc0',
                committer='Lemon🍋',
                committed_datetime='2022-12-14T16:28:47+00:00'),
            files={
                'Dockerfile': 'diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -13,6 +13,7 @@ RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && rm -f requirements.txt Pipfile Pipfile.lock \\\n  && pip uninstall -y pipenv\n \n+\n COPY src/ "${LAMBDA_TASK_ROOT}/src/"\n COPY utilsPython/ "${LAMBDA_TASK_ROOT}/utilsPython/"\n \n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='4bd08cd0b2874025ce32d0b1e9cd84ca20d59ce1',
                committer='Lemon🍋',
                committed_datetime='2022-12-14T16:32:13+00:00'),
            files={
                'Dockerfile': 'diff --git a/Dockerfile b/None\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/None\n@@ -1,20 +0,0 @@\n-#checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n-#checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n-FROM public.ecr.aws/lambda/python:3.9\n-\n-ENV PIP_ENV_VERSION="2022.1.8"\n-\n-ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n-COPY Pipfile Pipfile.lock ./\n-\n-RUN pip install pipenv==${PIP_ENV_VERSION} \\\n- && pipenv lock -r > requirements.txt \\\n- && pipenv run pip install -r requirements.txt --target "${LAMBDA_TASK_ROOT}" \\\n- && rm -f requirements.txt Pipfile Pipfile.lock \\\n- && pip uninstall -y pipenv\n-\n-\n-COPY src/ "${LAMBDA_TASK_ROOT}/src/"\n-COPY utilsPython/ "${LAMBDA_TASK_ROOT}/utilsPython/"\n-\n-CMD ["src.secrets_setup.image.src.app.handler"]\n'}
        ),
    ]
    return commits_mock


def mock_remove_file_with_two_equal_secret(self, last_commit_sha: str) -> List[Commit]:
    commits_mock = [
        Commit(
            metadata=CommitMetadata(
                commit_hash='d76977ac656abdaa77a7791a11adfb96efb48a35',
                committer='🍕🍕pizza',
                committed_datetime='2022-12-14T16:10:21+00:00'),
            files={
                'test3.py': 'diff --git a/test3.py b/test3.py\nindex 0000..0000 0000\n--- a/test3.py\n+++ b/test3.py\n@@ -1,4 +1,4 @@\n-\n+AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n \n if __name__ == \'__main__\':\n     print(\'test\')\n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='c211bfc4ae4514627f104ce0bf664dd9521d9c16',
                committer='🍕🍕pizza',
                committed_datetime='2022-12-14T16:28:47+00:00'),
            files={
                'test3.py': 'diff --git a/test3.py b/test3.py\nindex 0000..0000 0000\n--- a/test3.py\n+++ b/test3.py\n@@ -1,4 +1,5 @@\n AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n \n if __name__ == \'__main__\':\n+    AWS_ACCESS_KEY_ID = "AKIAZZZZZZZZZZZZZZZZ"\n     print(\'test\')\n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='8d96e18c1c924ba396211bf2d4fdd8d2418b8420',
                committer='🍕🍕pizza',
                committed_datetime='2022-12-14T16:32:13+00:00'),
            files={
                'test3.py': 'diff --git a/test3.py b/None\nindex 0000..0000 0000\n--- a/test3.py\n+++ b/None\n@@ -1,5 +0,0 @@\n-AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n-\n-if __name__ == \'__main__\':\n-    AWS_ACCESS_KEY_ID = "AKIAZZZZZZZZZZZZZZZZ"\n-    print(\'test\')\n'}
        ),
    ]
    return commits_mock


def mock_remove_file_with_two_secret(self, last_commit_sha: str) -> List[Commit]:
    commits_mock = [
        Commit(
            metadata=CommitMetadata(
                commit_hash='f0d117c1d65e90d4d6d7a1b6aaf4e23f4fd33b82',
                committer='🍻2secrets',
                committed_datetime='2022-12-14T16:10:21+00:00'),
            files={
                'main.py': 'diff --git a/main.py b/main.py\nindex 0000..0000 0000\n--- a/main.py\n+++ b/main.py\n@@ -1,3 +1,4 @@\n+AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n \n if __name__ == \'__main__\':\n \n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='1166ee830a03f6721fb8cba794496ee82895a0ba',
                committer='🍻2secrets',
                committed_datetime='2022-12-14T16:28:47+00:00'),
            files={
                'main.py': 'diff --git a/main.py b/main.py\nindex 0000..0000 0000\n--- a/main.py\n+++ b/main.py\n@@ -1,5 +1,5 @@\n AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n \n if __name__ == \'__main__\':\n-\n+    TEST_PASSWORD_1 = "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE"\n     print(\'test\')\n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='bdb3678fc44702132fa7d661a1c425e65c1e9dde',
                committer='🍻2secrets',
                committed_datetime='2022-12-14T16:32:13+00:00'),
            files={
                'main.py': 'diff --git a/main.py b/None\nindex 0000..0000 0000\n--- a/main.py\n+++ b/None\n@@ -1,5 +0,0 @@\n-AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n-\n-if __name__ == \'__main__\':\n-    TEST_PASSWORD_1 = "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE"\n-    print(\'test\')\n'}
        ),
    ]
    return commits_mock


def mock_git_repo_commits_rename_file(self, last_commit_sha: str) -> List[Commit]:
    commits_mock = [
        Commit(
            metadata=CommitMetadata(
                commit_hash='adef7360b86c62666f0a70521214220763b9c593',
                committer='Strawberry🍓',
                committed_datetime='2022-12-14T16:10:21+00:00'),
            files={
                'main.py': 'diff --git a/main.py b/main.py\nindex 0000..0000 0000\n--- a/main.py\n+++ b/main.py\n@@ -1,3 +1,3 @@\n-\n+AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n if __name__ == \'__main__\':\n     print(\'test\')\n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='7b12f891358f690f254476c80988bfa837f36ac6',
                committer='Strawberry🍓',
                committed_datetime='2022-12-14T16:28:47+00:00'),
            files={
                'main.py': 'diff --git a/main.py b/main.py\nindex 0000..0000 0000\n--- a/main.py\n+++ b/main.py\n@@ -1,3 +1,4 @@\n AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n+\n if __name__ == \'__main__\':\n     print(\'test\')\n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='2e1a500e688990e065fc6f1202bc64ed0ba53027',
                committer='Strawberry🍓',
                committed_datetime='2022-12-14T16:32:13+00:00'),
            renamed_files={
                'main.py': {
                    "rename_from": "main.py",
                    "rename_to": "test.py"
                }
            }
        ),
    ]
    return commits_mock


def mock_git_repo_commits_modify_and_rename_file(self, last_commit_sha: str) -> List[Commit]:
    """
    when we rename a file and modify it in the same commit it will consider as deleting the old file and creating a new file
    add secret to file +1
    rename the file and removed the secret- add removed_commit_hash
    """
    commits_mock = [
        Commit(
            metadata=CommitMetadata(
                commit_hash='62da8e5e04ec5c3a474467e9012bf3427cff0407',
                committer='🍹rename',
                committed_datetime='2022-12-14T16:10:21+00:00'),
            files={
                'test.py': 'diff --git a/test.py b/test.py\nindex 0000..0000 0000\n--- a/test.py\n+++ b/test.py\n@@ -1,4 +1,4 @@\n-\n+AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n \n if __name__ == \'__main__\':\n     print(\'test\')\n'}
        ),
        Commit(
            metadata=CommitMetadata(
                commit_hash='61ee79aea3d151a40c8e054295f330d233eaf7d5',
                committer='🍹rename',
                committed_datetime='2022-12-14T16:28:47+00:00'),
            files={
                'test.py': 'diff --git a/test.py b/None\nindex 0000..0000 0000\n--- a/test.py\n+++ b/None\n@@ -1,4 +0,0 @@\n-AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n-\n-if __name__ == \'__main__\':\n-    print(\'test\')\n',
                'test2.py': "diff --git a/None b/test2.py\nindex 0000..0000 0000\n--- a/None\n+++ b/test2.py\n@@ -0,0 +1,3 @@\n+\n+if __name__ == '__main__':\n+    print('test')\n"}
        ),
    ]
    return commits_mock


def mock_git_repo_multiline_json(self, last_commit_sha: str) -> List[Commit]:
    commits_mock = [
        Commit(
            metadata=CommitMetadata(
                commit_hash='6b99e255555eacbd5f79a4efe77dcacdc63ed10f',
                committer='🍽multiline_json',
                committed_datetime='2022-12-14T16:10:21+00:00'),
            files={
                'test-multiline-secrets.json': 'diff --git a/None b/test-multiline-secrets.json\nindex 0000..0000 0000\n--- a/None\n+++ b/test-multiline-secrets.json\n@@ -0,0 +1,30 @@\n+{\n+  "spec": [\n+    {\n+      "name": "SOME_NAME",\n+      "value": "some_value"\n+    },\n+    {\n+      "value": "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE",\n+      "name": "TEST_PASSWORD_1",\n+      "name1": "TEST_PASSWORD_2",\n+      "value1": "1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35"\n+    },\n+    {\n+      "name": "TEST_PASSWORD_3",\n+      "value": "PtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"\n+    },\n+    {\n+      "name": "TEST_PASSWORD_4",\n+      "value": "emDJTiv6H/hP6I8Tmr5+kUdpBIQDrXMwFO7AkmbwROf3rM6uNToJlIJW7H5ApfPmSGU0oWBwflV6Cd9pPu5nEvgxt4YMHZ0SQ85z"\n+    },\n+    {\n+      "name": "TEST_PASSWORD_LONG_1",\n+      "value": "m9+1ONt6FdpnByhlaKDwZ/jjA5gaPzrKY9q5G8cr6kjn092ogigwEOGGryjDqq/NkX1DnKGGG7iduJUJ48+Rv0tgpdVAxwLQuiszRnssmi2ck/Zf1iDFlNQtiE8rvXE6OTCsb6mrpyItLOVnEwsRSpggyRa3KLSuiguiZsK5KyXQ6BsiAclpLvz6QFBQoQkZNxownQrqgLwVwkK1gW0/EEm0m1ylz20ZeLgYO6tRSvKDW0lrgAI7g60F7/eJGv1UqQlxK58T+7u1UX/K11Q69e9jJE+LkQ932eY37U70oVbBVchHwSFKUoffernEaG9XP1tyEpIptPqVpcS2BMpktoR1p1yyWuxC5GsPc2RlPQzEbs3n5lPPnC/uEVu7/cJENSw5+9DzigiHYPz1Cq/p5HedIl5ysn2U2VFgHWekGBYin6ytfmF2Sx+hYqeRd6RcxyU434CXspWQqc330sp9q7vwPQHNecBrvG2Iy7mqVSvaJDnkZ8AN"\n+    },\n+    {\n+      "name": "TEST_PASSWORD_no_password",\n+      "value": "RandomP@ssw0rd"\n+    }\n+  ]\n+}\n\\ No newline at end of file\n'}
        ),
    ]
    return commits_mock


def mock_git_repo_multiline_terraform(self, last_commit_sha: str) -> List[Commit]:
    commits_mock = [
        Commit(
            metadata=CommitMetadata(
                commit_hash='6bee3eb2f69e06095395ae1d54c810c3a2a99841',
                committer='🥢multiline_terraform',
                committed_datetime='2022-12-14T16:10:21+00:00'),
            files={
                'secret_test.tf': 'diff --git a/secret_test.tf b/secret_test.tf\nindex 0000..0000 0000\n--- a/secret_test.tf\n+++ b/secret_test.tf\n@@ -0,0 +1,79 @@\n+resource "kubernetes_pod_v1" "test" {\n+  metadata {\n+    name = "terraform-example"\n+  }\n+\n+  spec {\n+    container {\n+      image = "nginx:1.21.6"\n+      name  = "example"\n+\n+      env {\n+        name  = "SOME_NAME"\n+        value = "some_value"\n+      }\n+      # name1 & value1 are not valid arguments\n+      env {\n+        value  = "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE"\n+        name = "TEST_PASSWORD_1"\n+        name1 = "TEST_PASSWORD_2"\n+        value1 = "1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35"\n+      }\n+      env {\n+        name  = "TEST_PASSWORD_3"\n+        // comment 1\n+        // comment 2\n+        // comment 3\n+        value = "PtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"\n+      }\n+      env {\n+        value = "emDJTiv6H/hP6I8Tmr5+kUdpBIQDrXMwFO7AkmbwROf3rM6uNToJlIJW7H5ApfPmSGU0oWBwflV6Cd9pPu5nEvgxt4YMHZ0SQ85z"\n+        # comment 1\n+        name  = "TEST_PASSWORD_4"\n+      }\n+      env {\n+        name  = "TEST_PASSWORD_LONG_1"\n+        value = "m9+1ONt6FdpnByhlaKDwZ/jjA5gaPzrKY9q5G8cr6kjn092ogigwEOGGryjDqq/NkX1DnKGGG7iduJUJ48+Rv0tgpdVAxwLQuiszRnssmi2ck/Zf1iDFlNQtiE8rvXE6OTCsb6mrpyItLOVnEwsRSpggyRa3KLSuiguiZsK5KyXQ6BsiAclpLvz6QFBQoQkZNxownQrqgLwVwkK1gW0/EEm0m1ylz20ZeLgYO6tRSvKDW0lrgAI7g60F7/eJGv1UqQlxK58T+7u1UX/K11Q69e9jJE+LkQ932eY37U70oVbBVchHwSFKUoffernEaG9XP1tyEpIptPqVpcS2BMpktoR1p1yyWuxC5GsPc2RlPQzEbs3n5lPPnC/uEVu7/cJENSw5+9DzigiHYPz1Cq/p5HedIl5ysn2U2VFgHWekGBYin6ytfmF2Sx+hYqeRd6RcxyU434CXspWQqc330sp9q7vwPQHNecBrvG2Iy7mqVSvaJDnkZ8AN"\n+      }\n+      env {\n+        name  = "TEST_PASSWORD_no_password"\n+        value = "RandomP@ssw0rd"\n+      }\n+\n+      port {\n+        container_port = 80\n+      }\n+\n+      liveness_probe {\n+        http_get {\n+          path = "/"\n+          port = 80\n+\n+          http_header {\n+            name  = "X-Custom-Header"\n+            value = "Awesome"\n+          }\n+        }\n+\n+        initial_delay_seconds = 3\n+        period_seconds        = 3\n+      }\n+    }\n+\n+    dns_config {\n+      nameservers = ["1.1.1.1", "8.8.8.8", "9.9.9.9"]\n+      searches    = ["example.com"]\n+\n+      option {\n+        name  = "ndots"\n+        value = 1\n+      }\n+\n+      option {\n+        name = "use-vc"\n+      }\n+    }\n+\n+    dns_policy = "None"\n+  }\n+}\n'}
        ),
    ]
    return commits_mock


def mock_git_repo_multiline_yml(self, last_commit_sha: str) -> List[Commit]:
    commits_mock = [
        Commit(
            metadata=CommitMetadata(
                commit_hash='cee6ad9d172ff447bd0afe8a478348b3ed6d3734',
                committer='🥢multiline_yml',
                committed_datetime='2022-12-14T16:10:21+00:00'),
            files={
                'test-multiline-secrets.yml': 'diff --git a/None b/test-multiline-secrets.yml\nindex 0000..0000 0000\n--- a/None\n+++ b/test-multiline-secrets.yml\n@@ -0,0 +1,15 @@\n+spec:\n+  - name: SOME_NAME\n+    value: some_value\n+  - value: Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE\n+    name: TEST_PASSWORD_1\n+    name1: TEST_PASSWORD_2\n+    value1: 1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35\n+  - name: TEST_PASSWORD_3\n+    value: PtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h\n+  - name: TEST_PASSWORD_4\n+    value: emDJTiv6H/hP6I8Tmr5+kUdpBIQDrXMwFO7AkmbwROf3rM6uNToJlIJW7H5ApfPmSGU0oWBwflV6Cd9pPu5nEvgxt4YMHZ0SQ85z\n+  - name: TEST_PASSWORD_LONG_1\n+    value: m9+1ONt6FdpnByhlaKDwZ/jjA5gaPzrKY9q5G8cr6kjn092ogigwEOGGryjDqq/NkX1DnKGGG7iduJUJ48+Rv0tgpdVAxwLQuiszRnssmi2ck/Zf1iDFlNQtiE8rvXE6OTCsb6mrpyItLOVnEwsRSpggyRa3KLSuiguiZsK5KyXQ6BsiAclpLvz6QFBQoQkZNxownQrqgLwVwkK1gW0/EEm0m1ylz20ZeLgYO6tRSvKDW0lrgAI7g60F7/eJGv1UqQlxK58T+7u1UX/K11Q69e9jJE+LkQ932eY37U70oVbBVchHwSFKUoffernEaG9XP1tyEpIptPqVpcS2BMpktoR1p1yyWuxC5GsPc2RlPQzEbs3n5lPPnC/uEVu7/cJENSw5+9DzigiHYPz1Cq/p5HedIl5ysn2U2VFgHWekGBYin6ytfmF2Sx+hYqeRd6RcxyU434CXspWQqc330sp9q7vwPQHNecBrvG2Iy7mqVSvaJDnkZ8AN\n+  - name: TEST_PASSWORD_no_password\n+    value: RandomP@ssw0rd\n'}
        ),
    ]
    return commits_mock


def get_random_string(length: int) -> str:
    chars = string.ascii_lowercase + string.ascii_letters
    result_str = ''.join(random.choice(chars) for _i in range(length))
    return result_str


def mock_case() -> Dict[str, str]:
    cases = [
        {
            "Dockerfile": "diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -4,6 +4,8 @@ FROM public.ecr.aws/lambda/python:3.9\n \n ENV PIP_ENV_VERSION=\"2022.1.8\"\n \n+ENV AWS_ACCESS_KEY_ID=\"wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY\"\n+\n COPY Pipfile Pipfile.lock ./\n \n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n"
        },
        {
            "Dockerfile": "diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -1,10 +1,9 @@\n #checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n-\n+ENV AWS_ACCESS_KEY_ID=\"wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY\"\n ENV PIP_ENV_VERSION=\"2022.1.8\"\n \n-ENV AWS_ACCESS_KEY_ID=\"wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY\"\n \n COPY Pipfile Pipfile.lock ./\n \n"
        },
        {
            "Dockerfile": "diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -1,7 +1,7 @@\n #checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n-ENV AWS_ACCESS_KEY_ID=\"wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY\"\n+ENV AWS_ACCESS_KEY_ID=\"AKIAZZZZZZZZZZZZZZZZ\"\n ENV PIP_ENV_VERSION=\"2022.1.8\"\n \n \n"
        },
        {
            "Dockerfile": "diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -1,7 +1,7 @@\n #checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n-ENV AWS_ACCESS_KEY_ID=\"AKIAZZZZZZZZZZZZZZZZ\"\n+\n ENV PIP_ENV_VERSION=\"2022.1.8\"\n \n \n"
        }
    ]
    return random.choice(cases)


def mock_git_repo_commits_too_much(self, last_commit_sha: str) -> List[Commit]:
    return [
        Commit(
            metadata=CommitMetadata(
                commit_hash=get_random_string(40),
                committer='Cherry🍒moi-moi-lots-of-commits',
                committed_datetime='2022-12-14T16:10:21+00:00'),
            files=mock_case()
        ) for _i in range(20000)
    ]


def mock_run_forever(repo: Repo, root_folder: str, git_commits: List[Any],
                     is_full_scan: bool = True) -> Generator[Commit, None, None]:
    res: List[Commit] = []
    while True:
        a = 1 + 1
        _ = a
    yield
    return res


def mock_commit_with_keyword_combinator() -> List[Commit]:
    return [Commit(
        metadata=CommitMetadata(
            commit_hash='8a21fa691e17907afee57e93b7820c5943b12746',
            committer='Cherry🍒',
            committed_datetime='2022-12-14T16:10:21+00:00'),
        files={
            'main.py': 'diff --git a/None b/main.py\nindex 0000..0000 0000\n--- a/None\n+++ b/main.py\n@@ -0,0 +1,4 @@\n+api_key = "wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMAAAKEY"\n+\n+if __name__ == "__main__":\n+    print(api_key)\n\\ No newline at end of file\n'}
    )]


def mock_get_commits(repo: Repo, last_commit_sha: Optional[str] = None,
                     branch: Optional[str] = None) -> List[Commit]:
    """
        add secret (secret1 added) - +1
        move the secret to different line - 0
        modify the secret value (secret1 removed=update + secret2 added) - +1
        remove the secret (secret2 removed=update) - 0
        add file with new secret (secret3 added) - +1
    """
    return []


def mock_get_commits_diff_iter_keyword_combinator(repo: Repo, root_folder: str, git_commits: List[Any],
                                                  is_full_scan: bool = True) -> Generator[Commit, None, None]:
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='c9b3268e15eb20fd406b9077a4c45875086d6c1b',
            committer='🐲dragon of commits🐲',
            committed_datetime='2022-11-14T16:10:21+00:00'),
        files={
            '.gitignore': "--- ''\n+++ .gitignore\n@@ -0,0 +1,50 @@\n+# These are some examples of commonly ignored file patterns.\n+# You should customize this list as applicable to your project.\n+# Learn more about .gitignore:\n+#     https://www.atlassian.com/git/tutorials/saving-changes/gitignore\n+\n+# Node artifact files\n+node_modules/\n+dist/\n+\n+# Compiled Java class files\n+*.class\n+\n+# Compiled Python bytecode\n+*.py[cod]\n+\n+# Log files\n+*.log\n+\n+# Package files\n+*.jar\n+\n+# Maven\n+target/\n+dist/\n+\n+# JetBrains IDE\n+.idea/\n+\n+# Unit test reports\n+TEST*.xml\n+\n+# Generated by MacOS\n+.DS_Store\n+\n+# Generated by Windows\n+Thumbs.db\n+\n+# Applications\n+*.app\n+*.exe\n+*.war\n+\n+# Large media files\n+*.mp4\n+*.tiff\n+*.avi\n+*.flv\n+*.mov\n+*.wmv\n+\n",
            'readme_mock-first-commit-mock.txt': "--- ''\n+++ readme_mock-first-commit-mock.txt\n@@ -0,0 +1 @@\n+('https://developer.atlassian.com/server/jira/platform/oath/#generate-an-rsa-public-private-key-pair')\n\\ No newline at end of file\n",
            'test-multiline-secrets-first-commit-mock.json': '--- \'\'\n+++ test-multiline-secrets-first-commit-mock.json\n@@ -0,0 +1,18 @@\n+{\n+  "spec": [\n+    {\n+    "name": "TEST_PASSWORD_3",\n+    "value": "ABCPtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"\n+    },\n+    {\n+      "name": "SOME_NAME",\n+      "value": "some_value"\n+    },\n+    {\n+      "value": "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE",\n+      "value1": "1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35",\n+      "name": "TEST_PASSWORD_1",\n+      "name1": "TEST_PASSWORD_2"\n+    }\n+  ]\n+}\n\\ No newline at end of file\n'
        }
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='8a21fa691e17907afee57e93b7820c5943b12746',
            committer='Cherry🍒',
            committed_datetime='2022-12-14T16:10:21+00:00'),
        files={
            'main.py': 'diff --git a/None b/main.py\nindex 0000..0000 0000\n--- a/None\n+++ b/main.py\n@@ -0,0 +1,4 @@\n+api_key = "wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMAAAKEY"\n+\n+if __name__ == "__main__":\n+    print(api_key)\n\\ No newline at end of file\n'}
    )


def mock_get_commits_diff_iter1(repo: Repo, root_folder: str, git_commits: List[Any],
                                is_full_scan: bool = True) -> Generator[Commit, None, None]:
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='c9b3268e15eb20fd406b9077a4c45875086d6c1b',
            committer='🐲dragon of commits🐲',
            committed_datetime='2022-11-14T16:10:21+00:00'),
        files={
            '.gitignore': "--- ''\n+++ .gitignore\n@@ -0,0 +1,50 @@\n+# These are some examples of commonly ignored file patterns.\n+# You should customize this list as applicable to your project.\n+# Learn more about .gitignore:\n+#     https://www.atlassian.com/git/tutorials/saving-changes/gitignore\n+\n+# Node artifact files\n+node_modules/\n+dist/\n+\n+# Compiled Java class files\n+*.class\n+\n+# Compiled Python bytecode\n+*.py[cod]\n+\n+# Log files\n+*.log\n+\n+# Package files\n+*.jar\n+\n+# Maven\n+target/\n+dist/\n+\n+# JetBrains IDE\n+.idea/\n+\n+# Unit test reports\n+TEST*.xml\n+\n+# Generated by MacOS\n+.DS_Store\n+\n+# Generated by Windows\n+Thumbs.db\n+\n+# Applications\n+*.app\n+*.exe\n+*.war\n+\n+# Large media files\n+*.mp4\n+*.tiff\n+*.avi\n+*.flv\n+*.mov\n+*.wmv\n+\n",
            'readme_mock-first-commit-mock.txt': "--- ''\n+++ readme_mock-first-commit-mock.txt\n@@ -0,0 +1 @@\n+('https://developer.atlassian.com/server/jira/platform/oath/#generate-an-rsa-public-private-key-pair')\n\\ No newline at end of file\n",
            'test-multiline-secrets-first-commit-mock.json': '--- \'\'\n+++ test-multiline-secrets-first-commit-mock.json\n@@ -0,0 +1,18 @@\n+{\n+  "spec": [\n+    {\n+    "name": "TEST_PASSWORD_3",\n+    "value": "ABCPtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"\n+    },\n+    {\n+      "name": "SOME_NAME",\n+      "value": "some_value"\n+    },\n+    {\n+      "value": "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE",\n+      "value1": "1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35",\n+      "name": "TEST_PASSWORD_1",\n+      "name1": "TEST_PASSWORD_2"\n+    }\n+  ]\n+}\n\\ No newline at end of file\n'
        }
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='8a21fa691e17907afee57e93b7820c5943b12746',
            committer='Cherry🍒',
            committed_datetime='2022-12-14T16:10:21+00:00'),
        files={
            'Dockerfile': 'diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -4,6 +4,8 @@ FROM public.ecr.aws/lambda/python:3.9\n \n ENV PIP_ENV_VERSION="2022.1.8"\n \n+ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n+\n COPY Pipfile Pipfile.lock ./\n \n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='d3249f33376b94a939b67a638aba4557b071875f',
            committer='🍒Cherry🍒',
            committed_datetime='2022-12-14T16:28:47+00:00'),
        files={
            'Dockerfile': 'diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -1,10 +1,9 @@\n #checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n-\n+ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n ENV PIP_ENV_VERSION="2022.1.8"\n \n-ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n \n COPY Pipfile Pipfile.lock ./\n \n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='3d79bba03c6f0ddcfb8334f531701942c4be0f32',
            committer='Cherry🍒',
            committed_datetime='2022-12-14T16:32:13+00:00'),
        files={
            'Dockerfile': 'diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -1,7 +1,7 @@\n #checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n-ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n+ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n ENV PIP_ENV_VERSION="2022.1.8"\n \n \n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='7dff3b21fc2563f51655f34f0d3601cdf79d0d5e',
            committer='🍒Cherry🍒',
            committed_datetime='2022-12-14T16:54:05+00:00'),
        files={
            'Dockerfile': 'diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -1,7 +1,7 @@\n #checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n-ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n+\n ENV PIP_ENV_VERSION="2022.1.8"\n \n \n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='6941281550a12659bdbe87c9a537f88124f78fac',
            committer='🍒Cherry🍒',
            committed_datetime='2022-12-14T16:57:26+00:00'),
        files={
            'main.py': 'diff --git a/None b/main.py\nindex 0000..0000 0000\n--- a/None\n+++ b/main.py\n@@ -0,0 +1,4 @@\n+AWS_ACCESS_TOKEN="AKIAZZZZZZZZZZZZZZZZ"\n+\n+if __name__ == "__main__":\n+    print(AWS_ACCESS_TOKEN)\n\\ No newline at end of file\n'}
    )


def mock_get_commits_diff_iter2(repo: Repo, root_folder: str, git_commits: List[Any],
                                is_full_scan: bool = True) -> Generator[Commit, None, None]:
    """
        add secret (secret1 added) - +1
        move the secret to different line - 0
        remove the secret (secret1 removed=update) - 0
        add secret (secret1 added - add the same secret - update) - 0
        move the secret to different line - 0
    """

    yield Commit(
        metadata=CommitMetadata(
            commit_hash='c9b3268e15eb20fd406b9077a4c45875086d6c1b',
            committer='🐲dragon of commits🐲',
            committed_datetime='2022-11-14T16:10:21+00:00'),
        files={
            '.gitignore': "--- ''\n+++ .gitignore\n@@ -0,0 +1,50 @@\n+# These are some examples of commonly ignored file patterns.\n+# You should customize this list as applicable to your project.\n+# Learn more about .gitignore:\n+#     https://www.atlassian.com/git/tutorials/saving-changes/gitignore\n+\n+# Node artifact files\n+node_modules/\n+dist/\n+\n+# Compiled Java class files\n+*.class\n+\n+# Compiled Python bytecode\n+*.py[cod]\n+\n+# Log files\n+*.log\n+\n+# Package files\n+*.jar\n+\n+# Maven\n+target/\n+dist/\n+\n+# JetBrains IDE\n+.idea/\n+\n+# Unit test reports\n+TEST*.xml\n+\n+# Generated by MacOS\n+.DS_Store\n+\n+# Generated by Windows\n+Thumbs.db\n+\n+# Applications\n+*.app\n+*.exe\n+*.war\n+\n+# Large media files\n+*.mp4\n+*.tiff\n+*.avi\n+*.flv\n+*.mov\n+*.wmv\n+\n",
            'readme_mock-first-commit-mock.txt': "--- ''\n+++ readme_mock-first-commit-mock.txt\n@@ -0,0 +1 @@\n+('https://developer.atlassian.com/server/jira/platform/oath/#generate-an-rsa-public-private-key-pair')\n\\ No newline at end of file\n",
            'test-multiline-secrets-first-commit-mock.json': '--- \'\'\n+++ test-multiline-secrets-first-commit-mock.json\n@@ -0,0 +1,18 @@\n+{\n+  "spec": [\n+    {\n+    "name": "TEST_PASSWORD_3",\n+    "value": "ABCPtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"\n+    },\n+    {\n+      "name": "SOME_NAME",\n+      "value": "some_value"\n+    },\n+    {\n+      "value": "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE",\n+      "value1": "1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35",\n+      "name": "TEST_PASSWORD_1",\n+      "name1": "TEST_PASSWORD_2"\n+    }\n+  ]\n+}\n\\ No newline at end of file\n'
        }
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='11e59e4e578c6ebcb48aae1e5e078a54c62920eb',
            committer='Mango🥭',
            committed_datetime='2022-12-14T16:10:21+00:00'),
        files={
            'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -5,7 +5,7 @@ FROM public.ecr.aws/lambda/python:3.9\n \n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n-\n+ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n \n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='c7c932ef4d31c487a921d2ce8544a4a468adf6b9',
            committer='🥭Mango🥭',
            committed_datetime='2022-12-14T16:28:47+00:00'),
        files={
            'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -2,10 +2,10 @@\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n \n-\n+ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n-ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n+\n \n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='4b8321e46217a87e21240afd88cdc0f1a861c0f5',
            committer='Mango🥭',
            committed_datetime='2022-12-14T16:32:13+00:00'),
        files={
            'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -2,7 +2,6 @@\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n \n-ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n \n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='7bb5c69d95b31bc2242bcf08ce25e74e953f9ae9',
            committer='🥭Mango🥭',
            committed_datetime='2022-12-14T16:54:05+00:00'),
        files={
            'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -4,7 +4,7 @@ FROM public.ecr.aws/lambda/python:3.9\n \n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n-\n+ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n \n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='2675bffd2662aae7025b7f3bb5fd384cdab355b1',
            committer='🥭Mango🥭',
            committed_datetime='2022-12-14T16:57:26+00:00'),
        files={
            'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -1,10 +1,11 @@\n #checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n+ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n \n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n-ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n+\n \n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n'}
    )


def mock_get_commits_diff_iter3(repo: Repo, root_folder: str, git_commits: List[Any],
                                is_full_scan: bool = True) -> Generator[Commit, None, None]:
    """
    add secret (secret1 added) - +1
    move the secret to different line - 0
    add secret equal to secret1 - +1
    remove one secret (secret1 - update add remove_commit_hash) - 0
    """
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='c9b3268e15eb20fd406b9077a4c45875086d6c1b',
            committer='🐲dragon of commits🐲',
            committed_datetime='2022-11-14T16:10:21+00:00'),
        files={
            '.gitignore': "--- ''\n+++ .gitignore\n@@ -0,0 +1,50 @@\n+# These are some examples of commonly ignored file patterns.\n+# You should customize this list as applicable to your project.\n+# Learn more about .gitignore:\n+#     https://www.atlassian.com/git/tutorials/saving-changes/gitignore\n+\n+# Node artifact files\n+node_modules/\n+dist/\n+\n+# Compiled Java class files\n+*.class\n+\n+# Compiled Python bytecode\n+*.py[cod]\n+\n+# Log files\n+*.log\n+\n+# Package files\n+*.jar\n+\n+# Maven\n+target/\n+dist/\n+\n+# JetBrains IDE\n+.idea/\n+\n+# Unit test reports\n+TEST*.xml\n+\n+# Generated by MacOS\n+.DS_Store\n+\n+# Generated by Windows\n+Thumbs.db\n+\n+# Applications\n+*.app\n+*.exe\n+*.war\n+\n+# Large media files\n+*.mp4\n+*.tiff\n+*.avi\n+*.flv\n+*.mov\n+*.wmv\n+\n",
            'readme_mock-first-commit-mock.txt': "--- ''\n+++ readme_mock-first-commit-mock.txt\n@@ -0,0 +1 @@\n+('https://developer.atlassian.com/server/jira/platform/oath/#generate-an-rsa-public-private-key-pair')\n\\ No newline at end of file\n",
            'test-multiline-secrets-first-commit-mock.json': '--- \'\'\n+++ test-multiline-secrets-first-commit-mock.json\n@@ -0,0 +1,18 @@\n+{\n+  "spec": [\n+    {\n+    "name": "TEST_PASSWORD_3",\n+    "value": "ABCPtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"\n+    },\n+    {\n+      "name": "SOME_NAME",\n+      "value": "some_value"\n+    },\n+    {\n+      "value": "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE",\n+      "value1": "1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35",\n+      "name": "TEST_PASSWORD_1",\n+      "name1": "TEST_PASSWORD_2"\n+    }\n+  ]\n+}\n\\ No newline at end of file\n'
        }
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='900b1e8f6f336a92e8f5fca3babca764e32c3b3d',
            committer='baguette🥖',
            committed_datetime='2022-12-14T16:10:21+00:00'),
        files={
            'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -1,6 +1,7 @@\n #checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n+ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n \n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='4229974aec78152c426b40db8b6912ba098f3add',
            committer='baguette🥖',
            committed_datetime='2022-12-14T16:28:47+00:00'),
        files={
            'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -1,11 +1,11 @@\n #checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n #checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n FROM public.ecr.aws/lambda/python:3.9\n-ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n+\n \n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n-\n+ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n \n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='3c8cb7eedb3986308c96713fc65b006adcf3bc44',
            committer='baguette🥖',
            committed_datetime='2022-12-14T16:32:13+00:00'),
        files={
            'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -6,7 +6,7 @@ FROM public.ecr.aws/lambda/python:3.9\n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n-\n+ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n  && pipenv run pip install -r requirements.txt --target "${LAMBDA_TASK_ROOT}" \\\n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='697308e61171e33224757e620aaf67b1a877c99d',
            committer='baguette🥖',
            committed_datetime='2022-12-14T16:54:05+00:00'),
        files={
            'folder1/folder2/Dockerfile': 'diff --git a/folder1/folder2/Dockerfile b/folder1/folder2/Dockerfile\nindex 0000..0000 0000\n--- a/folder1/folder2/Dockerfile\n+++ b/folder1/folder2/Dockerfile\n@@ -5,7 +5,7 @@ FROM public.ecr.aws/lambda/python:3.9\n \n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n-ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n+\n ENV AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n'}
    )
    yield Commit(  # this commit should make no difference - its just to have 5 commits returned from this mock
        metadata=CommitMetadata(
            commit_hash='697308e61171e332247z2i2bi0aaf67b1a877c99d',
            committer='baguette🥖',
            committed_datetime='2022-12-14T16:54:05+00:00'),
        files={
            'Dockerfile': 'diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -5,7 +5,7 @@ FROM public.ecr.aws/lambda/python:3.9\n \n ENV PIP_ENV_VERSION="2022.1.8"\n COPY Pipfile Pipfile.lock ./\n-ENV AWS_PIPY="something"\n+\n ENV AWS_DIP="ELSE"\n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && pipenv lock -r > requirements.txt \\\n'}
    )


def mock_get_commits_diff_remove_file(repo: Repo, root_folder: str, git_commits: List[Any],
                                      is_full_scan: bool = True) -> Generator[Commit, None, None]:
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='c9b3268e15eb20fd406b9077a4c45875086d6c1b',
            committer='🐲dragon of commits🐲',
            committed_datetime='2022-11-14T16:10:21+00:00'),
        files={
            '.gitignore': "--- ''\n+++ .gitignore\n@@ -0,0 +1,50 @@\n+# These are some examples of commonly ignored file patterns.\n+# You should customize this list as applicable to your project.\n+# Learn more about .gitignore:\n+#     https://www.atlassian.com/git/tutorials/saving-changes/gitignore\n+\n+# Node artifact files\n+node_modules/\n+dist/\n+\n+# Compiled Java class files\n+*.class\n+\n+# Compiled Python bytecode\n+*.py[cod]\n+\n+# Log files\n+*.log\n+\n+# Package files\n+*.jar\n+\n+# Maven\n+target/\n+dist/\n+\n+# JetBrains IDE\n+.idea/\n+\n+# Unit test reports\n+TEST*.xml\n+\n+# Generated by MacOS\n+.DS_Store\n+\n+# Generated by Windows\n+Thumbs.db\n+\n+# Applications\n+*.app\n+*.exe\n+*.war\n+\n+# Large media files\n+*.mp4\n+*.tiff\n+*.avi\n+*.flv\n+*.mov\n+*.wmv\n+\n",
            'readme_mock-first-commit-mock.txt': "--- ''\n+++ readme_mock-first-commit-mock.txt\n@@ -0,0 +1 @@\n+('https://developer.atlassian.com/server/jira/platform/oath/#generate-an-rsa-public-private-key-pair')\n\\ No newline at end of file\n",
            'test-multiline-secrets-first-commit-mock.json': '--- \'\'\n+++ test-multiline-secrets-first-commit-mock.json\n@@ -0,0 +1,18 @@\n+{\n+  "spec": [\n+    {\n+    "name": "TEST_PASSWORD_3",\n+    "value": "ABCPtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"\n+    },\n+    {\n+      "name": "SOME_NAME",\n+      "value": "some_value"\n+    },\n+    {\n+      "value": "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE",\n+      "value1": "1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35",\n+      "name": "TEST_PASSWORD_1",\n+      "name1": "TEST_PASSWORD_2"\n+    }\n+  ]\n+}\n\\ No newline at end of file\n'
        }
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='63342dbee285973a37770bbb1ff4258a3184901e',
            committer='Lemon🍋',
            committed_datetime='2022-12-14T16:10:21+00:00'),
        files={
            'Dockerfile': 'diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -4,6 +4,7 @@ FROM public.ecr.aws/lambda/python:3.9\n \n ENV PIP_ENV_VERSION="2022.1.8"\n \n+ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n COPY Pipfile Pipfile.lock ./\n \n RUN pip install pipenv==${PIP_ENV_VERSION} \\\n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='bca377900d08d442b1080893e50b8dc8276cfcc0',
            committer='Lemon🍋',
            committed_datetime='2022-12-14T16:28:47+00:00'),
        files={
            'Dockerfile': 'diff --git a/Dockerfile b/Dockerfile\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/Dockerfile\n@@ -13,6 +13,7 @@ RUN pip install pipenv==${PIP_ENV_VERSION} \\\n  && rm -f requirements.txt Pipfile Pipfile.lock \\\n  && pip uninstall -y pipenv\n \n+\n COPY src/ "${LAMBDA_TASK_ROOT}/src/"\n COPY utilsPython/ "${LAMBDA_TASK_ROOT}/utilsPython/"\n \n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='4bd08cd0b2874025ce32d0b1e9cd84ca20d59ce1',
            committer='Lemon🍋',
            committed_datetime='2022-12-14T16:32:13+00:00'),
        files={
            'Dockerfile': 'diff --git a/Dockerfile b/None\nindex 0000..0000 0000\n--- a/Dockerfile\n+++ b/None\n@@ -1,20 +0,0 @@\n-#checkov:skip=CKV_DOCKER_2:Healthcheck is not relevant for ephemral containers\n-#checkov:skip=CKV_DOCKER_3:User is created automatically by lambda runtime\n-FROM public.ecr.aws/lambda/python:3.9\n-\n-ENV PIP_ENV_VERSION="2022.1.8"\n-\n-ENV AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n-COPY Pipfile Pipfile.lock ./\n-\n-RUN pip install pipenv==${PIP_ENV_VERSION} \\\n- && pipenv lock -r > requirements.txt \\\n- && pipenv run pip install -r requirements.txt --target "${LAMBDA_TASK_ROOT}" \\\n- && rm -f requirements.txt Pipfile Pipfile.lock \\\n- && pip uninstall -y pipenv\n-\n-\n-COPY src/ "${LAMBDA_TASK_ROOT}/src/"\n-COPY utilsPython/ "${LAMBDA_TASK_ROOT}/utilsPython/"\n-\n-CMD ["src.secrets_setup.image.src.app.handler"]\n'}
    )


def mock_get_commits_diff_rename_file(repo: Repo, root_folder: str, git_commits: List[Any],
                                      is_full_scan: bool = True) -> Generator[Commit, None, None]:
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='c9b3268e15eb20fd406b9077a4c45875086d6c1b',
            committer='🐲dragon of commits🐲',
            committed_datetime='2022-11-14T16:10:21+00:00'),
        files={
            '.gitignore': "--- ''\n+++ .gitignore\n@@ -0,0 +1,50 @@\n+# These are some examples of commonly ignored file patterns.\n+# You should customize this list as applicable to your project.\n+# Learn more about .gitignore:\n+#     https://www.atlassian.com/git/tutorials/saving-changes/gitignore\n+\n+# Node artifact files\n+node_modules/\n+dist/\n+\n+# Compiled Java class files\n+*.class\n+\n+# Compiled Python bytecode\n+*.py[cod]\n+\n+# Log files\n+*.log\n+\n+# Package files\n+*.jar\n+\n+# Maven\n+target/\n+dist/\n+\n+# JetBrains IDE\n+.idea/\n+\n+# Unit test reports\n+TEST*.xml\n+\n+# Generated by MacOS\n+.DS_Store\n+\n+# Generated by Windows\n+Thumbs.db\n+\n+# Applications\n+*.app\n+*.exe\n+*.war\n+\n+# Large media files\n+*.mp4\n+*.tiff\n+*.avi\n+*.flv\n+*.mov\n+*.wmv\n+\n",
            'readme_mock-first-commit-mock.txt': "--- ''\n+++ readme_mock-first-commit-mock.txt\n@@ -0,0 +1 @@\n+('https://developer.atlassian.com/server/jira/platform/oath/#generate-an-rsa-public-private-key-pair')\n\\ No newline at end of file\n",
            'test-multiline-secrets-first-commit-mock.json': '--- \'\'\n+++ test-multiline-secrets-first-commit-mock.json\n@@ -0,0 +1,18 @@\n+{\n+  "spec": [\n+    {\n+    "name": "TEST_PASSWORD_3",\n+    "value": "ABCPtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"\n+    },\n+    {\n+      "name": "SOME_NAME",\n+      "value": "some_value"\n+    },\n+    {\n+      "value": "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE",\n+      "value1": "1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35",\n+      "name": "TEST_PASSWORD_1",\n+      "name1": "TEST_PASSWORD_2"\n+    }\n+  ]\n+}\n\\ No newline at end of file\n'
        }
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='adef7360b86c62666f0a70521214220763b9c593',
            committer='Strawberry🍓',
            committed_datetime='2022-12-14T16:10:21+00:00'),
        files={
            'main.py': 'diff --git a/main.py b/main.py\nindex 0000..0000 0000\n--- a/main.py\n+++ b/main.py\n@@ -1,3 +1,3 @@\n-\n+AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n if __name__ == \'__main__\':\n     print(\'test\')\n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='7b12f891358f690f254476c80988bfa837f36ac6',
            committer='Strawberry🍓',
            committed_datetime='2022-12-14T16:28:47+00:00'),
        files={
            'main.py': 'diff --git a/main.py b/main.py\nindex 0000..0000 0000\n--- a/main.py\n+++ b/main.py\n@@ -1,3 +1,4 @@\n AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n+\n if __name__ == \'__main__\':\n     print(\'test\')\n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='2e1a500e688990e065fc6f1202bc64ed0ba53027',
            committer='Strawberry🍓',
            committed_datetime='2022-12-14T16:32:13+00:00'),
        renamed_files={
            'main.py': {
                "rename_from": "main.py",
                "rename_to": "test.py"
            }
        }
    )


def mock_get_commits_diff_iter_modify_and_rename_file(repo: Repo, root_folder: str, git_commits: List[Any],
                                                      is_full_scan: bool = True) -> Generator[Commit, None, None]:
    """
    when we rename a file and modify it in the same commit it will consider as deleting the old file and creating a new file
    add secret to file +1
    rename the file and removed the secret- add removed_commit_hash
    """
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='c9b3268e15eb20fd406b9077a4c45875086d6c1b',
            committer='🐲dragon of commits🐲',
            committed_datetime='2022-11-14T16:10:21+00:00'),
        files={
            '.gitignore': "--- ''\n+++ .gitignore\n@@ -0,0 +1,50 @@\n+# These are some examples of commonly ignored file patterns.\n+# You should customize this list as applicable to your project.\n+# Learn more about .gitignore:\n+#     https://www.atlassian.com/git/tutorials/saving-changes/gitignore\n+\n+# Node artifact files\n+node_modules/\n+dist/\n+\n+# Compiled Java class files\n+*.class\n+\n+# Compiled Python bytecode\n+*.py[cod]\n+\n+# Log files\n+*.log\n+\n+# Package files\n+*.jar\n+\n+# Maven\n+target/\n+dist/\n+\n+# JetBrains IDE\n+.idea/\n+\n+# Unit test reports\n+TEST*.xml\n+\n+# Generated by MacOS\n+.DS_Store\n+\n+# Generated by Windows\n+Thumbs.db\n+\n+# Applications\n+*.app\n+*.exe\n+*.war\n+\n+# Large media files\n+*.mp4\n+*.tiff\n+*.avi\n+*.flv\n+*.mov\n+*.wmv\n+\n",
            'readme_mock-first-commit-mock.txt': "--- ''\n+++ readme_mock-first-commit-mock.txt\n@@ -0,0 +1 @@\n+('https://developer.atlassian.com/server/jira/platform/oath/#generate-an-rsa-public-private-key-pair')\n\\ No newline at end of file\n",
            'test-multiline-secrets-first-commit-mock.json': '--- \'\'\n+++ test-multiline-secrets-first-commit-mock.json\n@@ -0,0 +1,18 @@\n+{\n+  "spec": [\n+    {\n+    "name": "TEST_PASSWORD_3",\n+    "value": "ABCPtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"\n+    },\n+    {\n+      "name": "SOME_NAME",\n+      "value": "some_value"\n+    },\n+    {\n+      "value": "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE",\n+      "value1": "1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35",\n+      "name": "TEST_PASSWORD_1",\n+      "name1": "TEST_PASSWORD_2"\n+    }\n+  ]\n+}\n\\ No newline at end of file\n'
        }
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='62da8e5e04ec5c3a474467e9012bf3427cff0407',
            committer='🍹rename',
            committed_datetime='2022-12-14T16:10:21+00:00'),
        files={
            'test.py': 'diff --git a/test.py b/test.py\nindex 0000..0000 0000\n--- a/test.py\n+++ b/test.py\n@@ -1,4 +1,4 @@\n-\n+AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n \n if __name__ == \'__main__\':\n     print(\'test\')\n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='61ee79aea3d151a40c8e054295f330d233eaf7d5',
            committer='🍹rename',
            committed_datetime='2022-12-14T16:28:47+00:00'),
        files={
            'test.py': 'diff --git a/test.py b/None\nindex 0000..0000 0000\n--- a/test.py\n+++ b/None\n@@ -1,4 +0,0 @@\n-AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n-\n-if __name__ == \'__main__\':\n-    print(\'test\')\n',
            'test2.py': "diff --git a/None b/test2.py\nindex 0000..0000 0000\n--- a/None\n+++ b/test2.py\n@@ -0,0 +1,3 @@\n+\n+if __name__ == '__main__':\n+    print('test')\n"}
    )


def mock_get_commits_diff_iter_remove_file_with_two_equal_secret(repo: Repo, root_folder: str, git_commits: List[Any],
                                                                 is_full_scan: bool = True) -> Generator[
    Commit, None, None]:
    # yield Commit(
    #     metadata=CommitMetadata(
    #         commit_hash='c9b3268e15eb20fd406b9077a4c45875086d6c1b',
    #         committer='🐲dragon of commits🐲',
    #         committed_datetime='2022-11-14T16:10:21+00:00'),
    #     files={
    #         '.gitignore': "--- ''\n+++ .gitignore\n@@ -0,0 +1,50 @@\n+# These are some examples of commonly ignored file patterns.\n+# You should customize this list as applicable to your project.\n+# Learn more about .gitignore:\n+#     https://www.atlassian.com/git/tutorials/saving-changes/gitignore\n+\n+# Node artifact files\n+node_modules/\n+dist/\n+\n+# Compiled Java class files\n+*.class\n+\n+# Compiled Python bytecode\n+*.py[cod]\n+\n+# Log files\n+*.log\n+\n+# Package files\n+*.jar\n+\n+# Maven\n+target/\n+dist/\n+\n+# JetBrains IDE\n+.idea/\n+\n+# Unit test reports\n+TEST*.xml\n+\n+# Generated by MacOS\n+.DS_Store\n+\n+# Generated by Windows\n+Thumbs.db\n+\n+# Applications\n+*.app\n+*.exe\n+*.war\n+\n+# Large media files\n+*.mp4\n+*.tiff\n+*.avi\n+*.flv\n+*.mov\n+*.wmv\n+\n",
    #         'readme_mock-first-commit-mock.txt': "--- ''\n+++ readme_mock-first-commit-mock.txt\n@@ -0,0 +1 @@\n+('https://developer.atlassian.com/server/jira/platform/oath/#generate-an-rsa-public-private-key-pair')\n\\ No newline at end of file\n",
    #         'test-multiline-secrets-first-commit-mock.json': '--- \'\'\n+++ test-multiline-secrets-first-commit-mock.json\n@@ -0,0 +1,18 @@\n+{\n+  "spec": [\n+    {\n+    "name": "TEST_PASSWORD_3",\n+    "value": "ABCPtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"\n+    },\n+    {\n+      "name": "SOME_NAME",\n+      "value": "some_value"\n+    },\n+    {\n+      "value": "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE",\n+      "value1": "1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35",\n+      "name": "TEST_PASSWORD_1",\n+      "name1": "TEST_PASSWORD_2"\n+    }\n+  ]\n+}\n\\ No newline at end of file\n'
    #     }
    # )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='d76977ac656abdaa77a7791a11adfb96efb48a35',
            committer='🍕🍕pizza',
            committed_datetime='2022-12-14T16:10:21+00:00'),
        files={
            'test3.py': 'diff --git a/test3.py b/test3.py\nindex 0000..0000 0000\n--- a/test3.py\n+++ b/test3.py\n@@ -1,4 +1,4 @@\n-\n+AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n \n if __name__ == \'__main__\':\n     print(\'test\')\n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='c211bfc4ae4514627f104ce0bf664dd9521d9c16',
            committer='🍕🍕pizza',
            committed_datetime='2022-12-14T16:28:47+00:00'),
        files={
            'test3.py': 'diff --git a/test3.py b/test3.py\nindex 0000..0000 0000\n--- a/test3.py\n+++ b/test3.py\n@@ -1,4 +1,5 @@\n AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n \n if __name__ == \'__main__\':\n+    AWS_ACCESS_KEY_ID = "AKIAZZZZZZZZZZZZZZZZ"\n     print(\'test\')\n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='8d96e18c1c924ba396211bf2d4fdd8d2418b8420',
            committer='🍕🍕pizza',
            committed_datetime='2022-12-14T16:32:13+00:00'),
        files={
            'test3.py': 'diff --git a/test3.py b/None\nindex 0000..0000 0000\n--- a/test3.py\n+++ b/None\n@@ -1,5 +0,0 @@\n-AWS_ACCESS_KEY_ID="AKIAZZZZZZZZZZZZZZZZ"\n-\n-if __name__ == \'__main__\':\n-    AWS_ACCESS_KEY_ID = "AKIAZZZZZZZZZZZZZZZZ"\n-    print(\'test\')\n'}
    )


def mock_get_commits_diff_iter_remove_file_with_two_secret(repo: Repo, root_folder: str, git_commits: List[Any],
                                                           is_full_scan: bool = True) -> Generator[Commit, None, None]:
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='f0d117c1d65e90d4d6d7a1b6aaf4e23f4fd33b82',
            committer='🍻2secrets',
            committed_datetime='2022-12-14T16:10:21+00:00'),
        files={
            'main.py': 'diff --git a/main.py b/main.py\nindex 0000..0000 0000\n--- a/main.py\n+++ b/main.py\n@@ -1,3 +1,4 @@\n+AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n \n if __name__ == \'__main__\':\n \n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='1166ee830a03f6721fb8cba794496ee82895a0ba',
            committer='🍻2secrets',
            committed_datetime='2022-12-14T16:28:47+00:00'),
        files={
            'main.py': 'diff --git a/main.py b/main.py\nindex 0000..0000 0000\n--- a/main.py\n+++ b/main.py\n@@ -1,5 +1,5 @@\n AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n \n if __name__ == \'__main__\':\n-\n+    TEST_PASSWORD_1 = "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE"\n     print(\'test\')\n'}
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='bdb3678fc44702132fa7d661a1c425e65c1e9dde',
            committer='🍻2secrets',
            committed_datetime='2022-12-14T16:32:13+00:00'),
        files={
            'main.py': 'diff --git a/main.py b/None\nindex 0000..0000 0000\n--- a/main.py\n+++ b/None\n@@ -1,5 +0,0 @@\n-AWS_ACCESS_KEY_ID="wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"\n-\n-if __name__ == \'__main__\':\n-    TEST_PASSWORD_1 = "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE"\n-    print(\'test\')\n'}
    )


def mock_get_commits_diff_iter_multiline_json(repo: Repo, root_folder: str, git_commits: List[Any],
                                              is_full_scan: bool = True) -> Generator[Commit, None, None]:
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='6b99e255555eacbd5f79a4efe77dcacdc63ed10f',
            committer='🍽multiline_json',
            committed_datetime='2022-12-14T16:10:21+00:00'),
        files={
            'test-multiline-secrets.json': 'diff --git a/None b/test-multiline-secrets.json\nindex 0000..0000 0000\n--- a/None\n+++ b/test-multiline-secrets.json\n@@ -0,0 +1,30 @@\n+{\n+  "spec": [\n+    {\n+      "name": "SOME_NAME",\n+      "value": "some_value"\n+    },\n+    {\n+      "value": "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE",\n+      "name": "TEST_PASSWORD_1",\n+      "name1": "TEST_PASSWORD_2",\n+      "value1": "1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35"\n+    },\n+    {\n+      "name": "TEST_PASSWORD_3",\n+      "value": "PtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"\n+    },\n+    {\n+      "name": "TEST_PASSWORD_4",\n+      "value": "emDJTiv6H/hP6I8Tmr5+kUdpBIQDrXMwFO7AkmbwROf3rM6uNToJlIJW7H5ApfPmSGU0oWBwflV6Cd9pPu5nEvgxt4YMHZ0SQ85z"\n+    },\n+    {\n+      "name": "TEST_PASSWORD_LONG_1",\n+      "value": "m9+1ONt6FdpnByhlaKDwZ/jjA5gaPzrKY9q5G8cr6kjn092ogigwEOGGryjDqq/NkX1DnKGGG7iduJUJ48+Rv0tgpdVAxwLQuiszRnssmi2ck/Zf1iDFlNQtiE8rvXE6OTCsb6mrpyItLOVnEwsRSpggyRa3KLSuiguiZsK5KyXQ6BsiAclpLvz6QFBQoQkZNxownQrqgLwVwkK1gW0/EEm0m1ylz20ZeLgYO6tRSvKDW0lrgAI7g60F7/eJGv1UqQlxK58T+7u1UX/K11Q69e9jJE+LkQ932eY37U70oVbBVchHwSFKUoffernEaG9XP1tyEpIptPqVpcS2BMpktoR1p1yyWuxC5GsPc2RlPQzEbs3n5lPPnC/uEVu7/cJENSw5+9DzigiHYPz1Cq/p5HedIl5ysn2U2VFgHWekGBYin6ytfmF2Sx+hYqeRd6RcxyU434CXspWQqc330sp9q7vwPQHNecBrvG2Iy7mqVSvaJDnkZ8AN"\n+    },\n+    {\n+      "name": "TEST_PASSWORD_no_password",\n+      "value": "RandomP@ssw0rd"\n+    }\n+  ]\n+}\n\\ No newline at end of file\n'}
    )


def mock_get_commits_diff_iter_multiline_terraform(repo: Repo, root_folder: str, git_commits: List[Any],
                                                   is_full_scan: bool = True) -> Generator[Commit, None, None]:
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='6bee3eb2f69e06095395ae1d54c810c3a2a99841',
            committer='🥢multiline_terraform',
            committed_datetime='2022-12-14T16:10:21+00:00'),
        files={
            'secret_test.tf': 'diff --git a/secret_test.tf b/secret_test.tf\nindex 0000..0000 0000\n--- a/secret_test.tf\n+++ b/secret_test.tf\n@@ -0,0 +1,79 @@\n+resource "kubernetes_pod_v1" "test" {\n+  metadata {\n+    name = "terraform-example"\n+  }\n+\n+  spec {\n+    container {\n+      image = "nginx:1.21.6"\n+      name  = "example"\n+\n+      env {\n+        name  = "SOME_NAME"\n+        value = "some_value"\n+      }\n+      # name1 & value1 are not valid arguments\n+      env {\n+        value  = "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE"\n+        name = "TEST_PASSWORD_1"\n+        name1 = "TEST_PASSWORD_2"\n+        value1 = "1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35"\n+      }\n+      env {\n+        name  = "TEST_PASSWORD_3"\n+        // comment 1\n+        // comment 2\n+        // comment 3\n+        value = "PtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"\n+      }\n+      env {\n+        value = "emDJTiv6H/hP6I8Tmr5+kUdpBIQDrXMwFO7AkmbwROf3rM6uNToJlIJW7H5ApfPmSGU0oWBwflV6Cd9pPu5nEvgxt4YMHZ0SQ85z"\n+        # comment 1\n+        name  = "TEST_PASSWORD_4"\n+      }\n+      env {\n+        name  = "TEST_PASSWORD_LONG_1"\n+        value = "m9+1ONt6FdpnByhlaKDwZ/jjA5gaPzrKY9q5G8cr6kjn092ogigwEOGGryjDqq/NkX1DnKGGG7iduJUJ48+Rv0tgpdVAxwLQuiszRnssmi2ck/Zf1iDFlNQtiE8rvXE6OTCsb6mrpyItLOVnEwsRSpggyRa3KLSuiguiZsK5KyXQ6BsiAclpLvz6QFBQoQkZNxownQrqgLwVwkK1gW0/EEm0m1ylz20ZeLgYO6tRSvKDW0lrgAI7g60F7/eJGv1UqQlxK58T+7u1UX/K11Q69e9jJE+LkQ932eY37U70oVbBVchHwSFKUoffernEaG9XP1tyEpIptPqVpcS2BMpktoR1p1yyWuxC5GsPc2RlPQzEbs3n5lPPnC/uEVu7/cJENSw5+9DzigiHYPz1Cq/p5HedIl5ysn2U2VFgHWekGBYin6ytfmF2Sx+hYqeRd6RcxyU434CXspWQqc330sp9q7vwPQHNecBrvG2Iy7mqVSvaJDnkZ8AN"\n+      }\n+      env {\n+        name  = "TEST_PASSWORD_no_password"\n+        value = "RandomP@ssw0rd"\n+      }\n+\n+      port {\n+        container_port = 80\n+      }\n+\n+      liveness_probe {\n+        http_get {\n+          path = "/"\n+          port = 80\n+\n+          http_header {\n+            name  = "X-Custom-Header"\n+            value = "Awesome"\n+          }\n+        }\n+\n+        initial_delay_seconds = 3\n+        period_seconds        = 3\n+      }\n+    }\n+\n+    dns_config {\n+      nameservers = ["1.1.1.1", "8.8.8.8", "9.9.9.9"]\n+      searches    = ["example.com"]\n+\n+      option {\n+        name  = "ndots"\n+        value = 1\n+      }\n+\n+      option {\n+        name = "use-vc"\n+      }\n+    }\n+\n+    dns_policy = "None"\n+  }\n+}\n'}
    )


def mock_get_commits_diff_iter_multiline_yml(repo: Repo, root_folder: str, git_commits: List[Any],
                                             is_full_scan: bool = True) -> Generator[Commit, None, None]:
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='c9b3268e15eb20fd406b9077a4c45875086d6c1b',
            committer='🐲dragon of commits🐲',
            committed_datetime='2022-11-14T16:10:21+00:00'),
        files={
            '.gitignore': "--- ''\n+++ .gitignore\n@@ -0,0 +1,50 @@\n+# These are some examples of commonly ignored file patterns.\n+# You should customize this list as applicable to your project.\n+# Learn more about .gitignore:\n+#     https://www.atlassian.com/git/tutorials/saving-changes/gitignore\n+\n+# Node artifact files\n+node_modules/\n+dist/\n+\n+# Compiled Java class files\n+*.class\n+\n+# Compiled Python bytecode\n+*.py[cod]\n+\n+# Log files\n+*.log\n+\n+# Package files\n+*.jar\n+\n+# Maven\n+target/\n+dist/\n+\n+# JetBrains IDE\n+.idea/\n+\n+# Unit test reports\n+TEST*.xml\n+\n+# Generated by MacOS\n+.DS_Store\n+\n+# Generated by Windows\n+Thumbs.db\n+\n+# Applications\n+*.app\n+*.exe\n+*.war\n+\n+# Large media files\n+*.mp4\n+*.tiff\n+*.avi\n+*.flv\n+*.mov\n+*.wmv\n+\n",
            'readme_mock-first-commit-mock.txt': "--- ''\n+++ readme_mock-first-commit-mock.txt\n@@ -0,0 +1 @@\n+('https://developer.atlassian.com/server/jira/platform/oath/#generate-an-rsa-public-private-key-pair')\n\\ No newline at end of file\n",
            'test-multiline-secrets-first-commit-mock.json': '--- \'\'\n+++ test-multiline-secrets-first-commit-mock.json\n@@ -0,0 +1,18 @@\n+{\n+  "spec": [\n+    {\n+    "name": "TEST_PASSWORD_3",\n+    "value": "ABCPtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h"\n+    },\n+    {\n+      "name": "SOME_NAME",\n+      "value": "some_value"\n+    },\n+    {\n+      "value": "Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE",\n+      "value1": "1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35",\n+      "name": "TEST_PASSWORD_1",\n+      "name1": "TEST_PASSWORD_2"\n+    }\n+  ]\n+}\n\\ No newline at end of file\n'
        }
    )
    yield Commit(
        metadata=CommitMetadata(
            commit_hash='cee6ad9d172ff447bd0afe8a478348b3ed6d3734',
            committer='🥢multiline_yml',
            committed_datetime='2022-12-14T16:10:21+00:00'),
        files={
            'test-multiline-secrets.yml': 'diff --git a/None b/test-multiline-secrets.yml\nindex 0000..0000 0000\n--- a/None\n+++ b/test-multiline-secrets.yml\n@@ -0,0 +1,15 @@\n+spec:\n+  - name: SOME_NAME\n+    value: some_value\n+  - value: Zo5Zhexnf9TUggdn+zBKGEkmUUvuKzVN+/fKPaMBA4zVyef4irH5H5YfwoC4IqAX0DNoMD12yIF67nIdIMg13atW4WM33eNMfXlE\n+    name: TEST_PASSWORD_1\n+    name1: TEST_PASSWORD_2\n+    value1: 1Vab3xejyUlh89P6tUJNXgO4t07DzmomF4tPBwTbwt+sjXHg3G0MPMRpH/I2ho4gS5H3AKJkvJZj87V7/Qnp/rHdbMVYK1F0BX35\n+  - name: TEST_PASSWORD_3\n+    value: PtpfIZR+zZGPUWUYvLojqylVeEg63CBYN0FpGJ4yuH+9YxZZe8Uq7drEoTSfL64kElPEnVJk+H7SZr+wBoxN5qDWsbDmmUS2H76h\n+  - name: TEST_PASSWORD_4\n+    value: emDJTiv6H/hP6I8Tmr5+kUdpBIQDrXMwFO7AkmbwROf3rM6uNToJlIJW7H5ApfPmSGU0oWBwflV6Cd9pPu5nEvgxt4YMHZ0SQ85z\n+  - name: TEST_PASSWORD_LONG_1\n+    value: m9+1ONt6FdpnByhlaKDwZ/jjA5gaPzrKY9q5G8cr6kjn092ogigwEOGGryjDqq/NkX1DnKGGG7iduJUJ48+Rv0tgpdVAxwLQuiszRnssmi2ck/Zf1iDFlNQtiE8rvXE6OTCsb6mrpyItLOVnEwsRSpggyRa3KLSuiguiZsK5KyXQ6BsiAclpLvz6QFBQoQkZNxownQrqgLwVwkK1gW0/EEm0m1ylz20ZeLgYO6tRSvKDW0lrgAI7g60F7/eJGv1UqQlxK58T+7u1UX/K11Q69e9jJE+LkQ932eY37U70oVbBVchHwSFKUoffernEaG9XP1tyEpIptPqVpcS2BMpktoR1p1yyWuxC5GsPc2RlPQzEbs3n5lPPnC/uEVu7/cJENSw5+9DzigiHYPz1Cq/p5HedIl5ysn2U2VFgHWekGBYin6ytfmF2Sx+hYqeRd6RcxyU434CXspWQqc330sp9q7vwPQHNecBrvG2Iy7mqVSvaJDnkZ8AN\n+  - name: TEST_PASSWORD_no_password\n+    value: RandomP@ssw0rd\n'}
    )



import pytest

from checkov.terraform.module_loading.loaders.git_loader import GenericGitLoader
from checkov.terraform.module_loading.module_params import ModuleParams


@pytest.mark.parametrize("source, expected_root_module, expected_inner_module", [
    ("git::git@github.com:test-inner-module/out-module//inner-module?ref=main",
     "github.com:test-inner-module/out-module", "inner-module"),
    ("git::https://github.com:test-inner-module/out-module//inner-module?ref=main",
     "github.com:test-inner-module/out-module", "inner-module"),
    ("git::https://github.com:test-only-outer-module/out-module",
     "github.com:test-only-outer-module/out-module", ""),
    ("git::ssh://github.com:test-only-outer-module/out-module",
     "github.com:test-only-outer-module/out-module", ""),
    ("https://github.com:test-only-outer-module/out-module",
     "github.com:test-only-outer-module/out-module", ""),
    ("https://github.com:test-with-inner-module-no-git-prefix/out-module//in-module",
     "github.com:test-with-inner-module-no-git-prefix/out-module", "in-module")
]
                         )
def test__parse_module_source(source: str, expected_root_module: str, expected_inner_module: str) -> None:
    git_loader = GenericGitLoader()
    module_params = ModuleParams(
        root_dir="test",
        current_dir="test",
        source=source,
        source_version="source_version",
        dest_dir="test",
        external_modules_folder_name="test",
        inner_module="",
        tf_managed=False
    )
    module_source = git_loader._parse_module_source(module_params)
    assert module_source.root_module == expected_root_module
    assert module_source.inner_module == expected_inner_module



import unittest

from checkov.terraform.checks.resource.gcp.GKEAliasIpEnabled import check
from checkov.common.models.enums import CheckResult
import hcl2


resource_conf = '''
resource "google_container_cluster" "fail" {
  name                     = "fail-cluster"
}

resource "google_container_cluster" "success" {
  name                     = "success-cluster"
  ip_allocation_policy {}
}
'''


class TestGKEAliasIpEnabled(unittest.TestCase):

    def test_failure(self):
        resource = hcl2.loads(resource_conf)[
            'resource'][0]['google_container_cluster']['fail']
        scan_result = check.scan_resource_conf(conf=resource)
        self.assertEqual(CheckResult.FAILED, scan_result)

    def test_success(self):
        resource = hcl2.loads(resource_conf)[
            'resource'][1]['google_container_cluster']['success']

        scan_result = check.scan_resource_conf(
            conf=resource)
        self.assertEqual(CheckResult.PASSED, scan_result)


if __name__ == '__main__':
    unittest.main()



import unittest
import hcl2

from checkov.terraform.checks.resource.aws.EC2EBSOptimized import check
from checkov.common.models.enums import CheckResult


class TestEC2EBSOptimized(unittest.TestCase):

    def test_failure(self):
        hcl_res = hcl2.loads("""
            resource "aws_instance" "foo" {
              subnet_id   = some_id
            }
        """)
        resource_conf = hcl_res['resource'][0]['aws_instance']['foo']
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILED, scan_result)

    def test_success_default(self):
        hcl_res = hcl2.loads("""
            resource "aws_instance" "foo" {
              subnet_id     = some_id
              ebs_optimized = true
            }
        """)
        resource_conf = hcl_res['resource'][0]['aws_instance']['foo']
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.PASSED, scan_result)


if __name__ == '__main__':
    unittest.main()



from aws_cdk import core
from aws_cdk import aws_sqs as sqs
class SqsQueueWithKmsKeyStack(core.Stack):

    def __init__(self, scope: core.Construct, id: str, **kwargs) -> None:
        super().__init__(scope, id, **kwargs)

        # Create an SQS queue with KMS encryption
        queue = sqs.Queue(self, "MySqsQueue",
            encryption=sqs.QueueEncryption.KMS,
            visibility_timeout=300  # Other properties for the queue
        )

app = core.App()
SqsQueueWithKmsKeyStack(app, "SqsQueueWithKmsKeyStack")
app.synth()



class SqsQueueWithKmsKeyIdStack(core.Stack):

    def __init__(self, scope: core.Construct, id: str, **kwargs) -> None:
        super().__init__(scope, id, **kwargs)

        # Define an SQS queue with a specific KmsMasterKeyId
        queue = sqs.CfnQueue(self, "MySqsQueue",
            visibility_timeout=300  # Other properties for the queue
        )

app = core.App()
SqsQueueWithKmsKeyIdStack(app, "SqsQueueWithKmsKeyIdStack")
app.synth()



import hcl2
import unittest

from checkov.terraform.checks.resource.aws.MQBrokerNotPubliclyExposed import check
from checkov.common.models.enums import CheckResult


class TestMQBrokerNotPubliclyExposed(unittest.TestCase):

    def test_failure_mqbroker_logging(self):
        hcl_res = hcl2.loads("""
        resource "aws_mq_broker" "example" {
            broker_name = "example"

            engine_type         = "ActiveMQ"
            engine_version      = "5.15.0"
            host_instance_type  = "mq.t2.micro"
            publicly_accessible = true

            user {
                username = "ExampleUser"
                password = "MindTheGap"  # checkov:skip=CKV_SECRET_6 test secret
            }
        }
        """)
        resource_conf = hcl_res['resource'][0]['aws_mq_broker']['example']
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILED, scan_result)

    def test_success_mqbroker_logging(self):
        hcl_res = hcl2.loads("""
        resource "aws_mq_broker" "example" {
            broker_name = "example"

            engine_type         = "ActiveMQ"
            engine_version      = "5.15.0"
            host_instance_type  = "mq.t2.micro"
            publicly_accessible = false

            user {
                username = "ExampleUser"
                password = "MindTheGap"
            }
        }
        """)
        resource_conf = hcl_res['resource'][0]['aws_mq_broker']['example']
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.PASSED, scan_result)

    def test_success_missing_mqbroker_logging(self):
        hcl_res = hcl2.loads("""
        resource "aws_mq_broker" "example" {
            broker_name = "example"

            engine_type         = "ActiveMQ"
            engine_version      = "5.15.0"
            host_instance_type  = "mq.t2.micro"

            user {
                username = "ExampleUser"
                password = "MindTheGap"
            }
        }
        """)
        resource_conf = hcl_res['resource'][0]['aws_mq_broker']['example']
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.PASSED, scan_result)


if __name__ == '__main__':
    unittest.main()



from unittest import TestCase
import os

from checkov.terraform.graph_builder.graph_components.block_types import BlockType
from checkov.terraform.graph_builder.graph_components.blocks import TerraformBlock
from checkov.terraform.graph_manager import TerraformGraphManager
from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector

TEST_DIRNAME = os.path.dirname(os.path.realpath(__file__))


class TestBlocks(TestCase):
    def test_update_inner_attribute_1(self):
        config = {
            "aws_security_group": {
                "test": {
                    "name": ["test"],
                    "vpc_id": ["${aws_vpc.vpc_main.id}"],
                    "tags": [{"Name": "test"}],
                    "description": ["test - Elasticsearch Cluster"],
                    "ingress": [
                        {
                            "from_port": [443],
                            "to_port": [443],
                            "protocol": ["tcp"],
                            "security_groups": [
                                ["${aws_security_group.test.id}", "${data.aws_security_group.test.id}"]
                            ],
                        }
                    ],
                }
            }
        }

        block = TerraformBlock(
            name="aws_security_group.test",
            config=config,
            path="test_path",
            block_type=BlockType.RESOURCE,
            attributes=config["aws_security_group"]["test"],
        )

        block.update_inner_attribute(
            attribute_key="ingress.security_groups.0", nested_attributes=block.attributes, value_to_update="sg-0"
        )
        block.update_inner_attribute(
            attribute_key="ingress.security_groups.1", nested_attributes=block.attributes, value_to_update="sg-1"
        )

        self.assertEqual(
            "sg-0",
            block.attributes["ingress.security_groups.0"],
            f"failed to update ingress.security_groups.0, got {block.attributes['ingress.security_groups.0']}",
        )
        self.assertEqual(
            "sg-1",
            block.attributes["ingress.security_groups.1"],
            f"failed to update ingress.security_groups.1, got {block.attributes['ingress.security_groups.1']}",
        )
        self.assertEqual(
            "sg-0",
            block.attributes["ingress"]["security_groups"][0],
            f"failed to update block.attributes['ingress']['security_groups'][0], got {block.attributes['ingress']['security_groups'][0]}",
        )
        self.assertEqual(
            "sg-1",
            block.attributes["ingress"]["security_groups"][1],
            f"failed to update block.attributes['ingress']['security_groups'][1], got {block.attributes['ingress']['security_groups'][1]}",
        )

    def test_update_inner_attribute_2(self):
        config = {
            "aws_security_group": {
                "test": {
                    "name": ["test"],
                    "vpc_id": ["${aws_vpc.vpc_main.id}"],
                    "ingress": [
                        {
                            "from_port": [53],
                            "to_port": [53],
                            "protocol": ["udp"],
                            "security_groups": [
                                [
                                    "${data.test1.id}",
                                    "${data.test2.id}",
                                    "${data.test3.id}",
                                    "${data.test4.id}",
                                    "${data.test5.id}",
                                    "${data.test6.id}",
                                ]
                            ],
                            "cidr_blocks": [["test1", "${var.test2}", "${var.test4}"]],
                        },
                        {
                            "from_port": [53],
                            "to_port": [53],
                            "protocol": ["tcp"],
                            "security_groups": [
                                [
                                    "${data.test1.id}",
                                    "${data.test2.id}",
                                    "${data.test3.id}",
                                    "${data.test4.id}",
                                    "${data.test5.id}",
                                    "${data.test6.id}",
                                ]
                            ],
                            "cidr_blocks": [["test", "${var.test}", "${var.v3}"]],
                        },
                    ],
                }
            }
        }

        block = TerraformBlock(
            name="aws_security_group.test",
            config=config,
            path="test_path",
            block_type=BlockType.RESOURCE,
            attributes=config["aws_security_group"]["test"],
        )

        block.update_inner_attribute(
            attribute_key="ingress.0.cidr_blocks.1", nested_attributes=block.attributes, value_to_update="sg-1"
        )

        self.assertEqual(
            "sg-1",
            block.attributes["ingress.0.cidr_blocks.1"],
            f"failed to update ingress.0.cidr_blocks.1, got {block.attributes['ingress.0.cidr_blocks.1']}",
        )
        self.assertEqual(
            "sg-1",
            block.attributes["ingress"][0]["cidr_blocks"][1],
            f"failed to update block.attributes['ingress'][0]['cidr_blocks'][1], got {block.attributes['ingress'][0]['cidr_blocks'][1]}",
        )

    def test_update_inner_attribute_3(self):
        config = {
            "aws_iam_policy_document": {
                "vcs_webhook_step_function_execution_policy": {
                    "statement": [
                        {
                            "actions": [["events:DescribeRule", "events:PutRule", "events:PutTargets"]],
                            "effect": ["Allow"],
                            "resources": [
                                [
                                    "arn:aws:events:${var.region}:${data.aws_caller_identity.current.account_id}:rule/StepFunctionsGetEventsForECSTaskRule",
                                    "arn:aws:events:${var.region}:${data.aws_caller_identity.current.account_id}:rule/StepFunctionsGetEventsForStepFunctionsExecutionRule",
                                ]
                            ],
                        },
                        {
                            "actions": [["states:StartExecution"]],
                            "effect": ["Allow"],
                            "resources": [
                                [
                                    "arn:aws:states:${var.region}:${data.aws_caller_identity.current.account_id}:stateMachine:${module.consts.bc_checkov_scanner_step_function_name}*"
                                ]
                            ],
                        },
                        {
                            "actions": [["lambda:InvokeFunction"]],
                            "effect": ["Allow"],
                            "resources": [
                                "${formatlist(\"%s%s\",\"arn:aws:lambda:${var.region}:${data.aws_caller_identity.current.account_id}:function:\",concat(['${local.vcs_webhook_lambda_name}', '${local.customer_api_lambda}']))}"
                            ],
                        },
                    ]
                }
            }
        }
        block = TerraformBlock(
            name="aws_iam_policy_document.vcs_webhook_step_function_execution_policy",
            config=config,
            path="test_path",
            block_type=BlockType.DATA,
            attributes=config["aws_iam_policy_document"]["vcs_webhook_step_function_execution_policy"],
        )
        block.update_inner_attribute(
            attribute_key="statement.1.resources.0",
            nested_attributes={
                "statement": [
                    {
                        "actions": ["events:DescribeRule", "events:PutRule", "events:PutTargets"],
                        "effect": "Allow",
                        "resources": [
                            "arn:aws:events:${var.region}:${data.aws_caller_identity.current.account_id}:rule/StepFunctionsGetEventsForECSTaskRule",
                            "arn:aws:events:${var.region}:${data.aws_caller_identity.current.account_id}:rule/StepFunctionsGetEventsForStepFunctionsExecutionRule",
                        ],
                    },
                    {
                        "actions": "states:StartExecution",
                        "effect": "Allow",
                        "resources": "arn:aws:states:${var.region}:${data.aws_caller_identity.current.account_id}:stateMachine:bc-vcs-scanner-sfn*",
                    },
                    {
                        "actions": "lambda:InvokeFunction",
                        "effect": "Allow",
                        "resources": "${formatlist(\"%s%s\",\"arn:aws:lambda:${var.region}:${data.aws_caller_identity.current.account_id}:function:\",concat(['${local.vcs_webhook_lambda_name}', '${local.customer_api_lambda}']))}",
                    },
                ],
                "statement.0": {
                    "actions": ["events:DescribeRule", "events:PutRule", "events:PutTargets"],
                    "effect": "Allow",
                    "resources": [
                        "arn:aws:events:${var.region}:${data.aws_caller_identity.current.account_id}:rule/StepFunctionsGetEventsForECSTaskRule",
                        "arn:aws:events:${var.region}:${data.aws_caller_identity.current.account_id}:rule/StepFunctionsGetEventsForStepFunctionsExecutionRule",
                    ],
                },
                "statement.0.actions": ["events:DescribeRule", "events:PutRule", "events:PutTargets"],
                "statement.0.actions.0": "events:DescribeRule",
                "statement.0.actions.1": "events:PutRule",
                "statement.0.actions.2": "events:PutTargets",
                "statement.0.effect": "Allow",
                "statement.0.resources": [
                    "arn:aws:events:${var.region}:${data.aws_caller_identity.current.account_id}:rule/StepFunctionsGetEventsForECSTaskRule",
                    "arn:aws:events:${var.region}:${data.aws_caller_identity.current.account_id}:rule/StepFunctionsGetEventsForStepFunctionsExecutionRule",
                ],
                "statement.0.resources.0": "arn:aws:events:${var.region}:${data.aws_caller_identity.current.account_id}:rule/StepFunctionsGetEventsForECSTaskRule",
                "statement.0.resources.1": "arn:aws:events:${var.region}:${data.aws_caller_identity.current.account_id}:rule/StepFunctionsGetEventsForStepFunctionsExecutionRule",
                "statement.1": {
                    "resources": "arn:aws:states:${var.region}:${data.aws_caller_identity.current.account_id}:stateMachine:bc-vcs-scanner-sfn*"
                },
                "statement.1.actions": "states:StartExecution",
                "statement.1.actions.0": "states:StartExecution",
                "statement.1.effect": "Allow",
                "statement.1.resources": "arn:aws:states:${var.region}:${data.aws_caller_identity.current.account_id}:stateMachine:bc-vcs-scanner-sfn*",
                "statement.1.resources.0": "arn:aws:states:${var.region}:${data.aws_caller_identity.current.account_id}:stateMachine:bc-vcs-scanner-sfn*",
                "statement.2": {
                    "actions": "lambda:InvokeFunction",
                    "effect": "Allow",
                    "resources": "${formatlist(\"%s%s\",\"arn:aws:lambda:${var.region}:${data.aws_caller_identity.current.account_id}:function:\",concat(['${local.vcs_webhook_lambda_name}', '${local.customer_api_lambda}']))}",
                },
                "statement.2.actions": "lambda:InvokeFunction",
                "statement.2.actions.0": "lambda:InvokeFunction",
                "statement.2.effect": "Allow",
                "statement.2.resources": "${formatlist(\"%s%s\",\"arn:aws:lambda:${var.region}:${data.aws_caller_identity.current.account_id}:function:\",concat(['${local.vcs_webhook_lambda_name}', '${local.customer_api_lambda}']))}",
            },
            value_to_update="arn:aws:states:${var.region}:${data.aws_caller_identity.current.account_id}:stateMachine:bc-vcs-scanner-sfn*",
        )
        self.assertIn(
            block.attributes["statement.0.resources.1"],
            [
                "arn:aws:events:${var.region}:${data.aws_caller_identity.current.account_id}:rule/StepFunctionsGetEventsForECSTaskRule",
                "arn:aws:events:${var.region}:${data.aws_caller_identity.current.account_id}:rule/StepFunctionsGetEventsForStepFunctionsExecutionRule",
            ],
        )
        self.assertIn(
            block.attributes["statement.0.resources.0"],
            [
                "arn:aws:events:${var.region}:${data.aws_caller_identity.current.account_id}:rule/StepFunctionsGetEventsForECSTaskRule",
                "arn:aws:events:${var.region}:${data.aws_caller_identity.current.account_id}:rule/StepFunctionsGetEventsForStepFunctionsExecutionRule",
            ],
        )

    def test_update_complex_key(self):
        config = {
            "labels": [
                {
                    "app.kubernetes.io/name": "${local.name}",
                    "app.kubernetes.io/instance": "hpa",
                    "app.kubernetes.io/version": "1.0.0",
                    "app.kubernetes.io/managed-by": "terraform",
                }
            ]
        }
        attributes = {
            "labels": {
                "app.kubernetes.io/name": "${local.name}",
                "app.kubernetes.io/instance": "hpa",
                "app.kubernetes.io/version": "1.0.0",
                "app.kubernetes.io/managed-by": "terraform",
            },
            "labels.app.kubernetes.io/name": "${local.name}",
            "labels.app.kubernetes.io/instance": "hpa",
            "labels.app.kubernetes.io/version": "1.0.0",
            "labels.app.kubernetes.io/managed-by": "terraform",
        }
        block = TerraformBlock(
            name="test_local_name", config=config, path="", block_type=BlockType.LOCALS, attributes=attributes
        )

        block.update_inner_attribute(
            attribute_key="labels.app.kubernetes.io/name", nested_attributes=attributes, value_to_update="dummy value"
        )
        self.assertEqual("dummy value", block.attributes["labels.app.kubernetes.io/name"])

    def test_update_complex_key2(self):
        config = {}
        attributes = {
            "var.owning_account": {
                "route_to": None,
                "route_to_cidr_blocks": "${local.allowed_cidrs}",
                "static_routes": None,
                "subnet_ids": "${local.own_vpc.private_subnet_ids}",
                "subnet_route_table_ids": "${local.own_vpc.private_route_table_ids}",
                "transit_gateway_vpc_attachment_id": None,
                "vpc_cidr": "${local.own_vpc.vpc_cidr}",
                "vpc_id": "${local.own_vpc.vpc_id}",
            }
        }
        block = TerraformBlock(
            name="test_local_name", config=config, path="", block_type=BlockType.LOCALS, attributes=attributes
        )
        value_to_update = "test"
        block.update_inner_attribute(
            attribute_key="var.owning_account.vpc_cidr", nested_attributes=attributes, value_to_update=value_to_update
        )
        self.assertDictEqual(
            {"var.owning_account": block.attributes["var.owning_account"]},
            {
                "var.owning_account": {
                    "route_to": None,
                    "route_to_cidr_blocks": "${local.allowed_cidrs}",
                    "static_routes": None,
                    "subnet_ids": "${local.own_vpc.private_subnet_ids}",
                    "subnet_route_table_ids": "${local.own_vpc.private_route_table_ids}",
                    "transit_gateway_vpc_attachment_id": None,
                    "vpc_cidr": "test",
                    "vpc_id": "${local.own_vpc.vpc_id}",
                }
            },
        )

    def test_update_inner_attribute_bad_index(self):
        config = {"aws_security_group": {"test": {}}}

        nested_attributes = {
            "provisioner/remote-exec.connection": {"private_key": "${file(var.ssh_key_path)}", "user": "ec2-user"},
            "provisioner/remote-exec.connection.private_key": "${file(var.ssh_key_path)}",
            "provisioner/remote-exec.connection.user": "ec2-user",
            "provisioner/remote-exec.inline": ["command"],
            "provisioner/remote-exec.inline.0": "command0",
            "provisioner/remote-exec.inline.1": "command1",
            "provisioner/remote-exec.inline.2": "command2",
            "provisioner/remote-exec.inline.3": "command3",
            "provisioner/remote-exec.inline.4": "command4",
        }
        block = TerraformBlock(
            name="aws_security_group.test",
            config=config,
            path="test_path",
            block_type=BlockType.RESOURCE,
            attributes=nested_attributes,
        )

        block.update_inner_attribute(
            attribute_key="provisioner/remote-exec.inline.3",
            nested_attributes=nested_attributes,
            value_to_update="new_command_3",
        )

        self.assertEqual(
            "new_command_3",
            block.attributes["provisioner/remote-exec.inline.3"],
            f"failed to update provisioner/remote-exec.inline.3, got {block.attributes['provisioner/remote-exec.inline.3']}",
        )

    def test_update_inner_attribute_bad_map_entry(self):
        config = {"aws_security_group": {"test": {}}}

        nested_attributes = {
            "triggers": {
                "change_endpoint_name": '${md5("my_dev_endpoint")}',
                "change_extra_jars_s3_path": "${md5()}",
                "change_extra_python_libs_s3_path": "${md5()}",
                "change_number_of_nodes": '${md5("2")}',
                "change_public_keys": '${md5("${var.glue_endpoint_public_keys}")}',
                "change_region": '${md5("us-east-1")}',
                "change_role": '${md5("arn:aws:iam::111111111111:role/my_role")}',
                "change_security_configuration": "${md5()}",
                "change_security_group_ids": '${md5("${var.glue_endpoint_security_group_ids}")}',
                "change_subnet_id": "${md5()}",
            },
            "provisioner/local-exec": {
                "command": "echo 'info: destroy ignored because part of apply'",
                "when": "destroy",
            },
            "provisioner/local-exec.command": "echo 'info: destroy ignored because part of apply'",
            "provisioner/local-exec.environment": {
                "endpoint_name": "${var.glue_endpoint_name}",
                "extra_jars_s3_path": "${var.glue_endpoint_extra_jars_libraries}",
                "extra_python_libs_s3_path": "${var.glue_endpoint_extra_python_libraries}",
                "number_of_nodes": "${var.glue_endpoint_number_of_dpus}",
                "public_keys": '${join(",",var.glue_endpoint_public_keys)}',
                "region": "${var.aws_region}",
                "role_arn": "${var.glue_endpoint_role}",
                "security_configuration": "${var.glue_endpoint_security_configuration}",
                "security_group_ids": '${join(",",var.glue_endpoint_security_group_ids)}',
                "subnet_id": "${var.glue_endpoint_subnet_id}",
            },
            "provisioner/local-exec.environment.endpoint_name": "my_dev_endpoint",
            "provisioner/local-exec.environment.extra_jars_s3_path": "",
            "provisioner/local-exec.environment.extra_python_libs_s3_path": "",
            "provisioner/local-exec.environment.number_of_nodes": 2,
            "provisioner/local-exec.environment.public_keys": '${join(",",var.glue_endpoint_public_keys)}',
            "provisioner/local-exec.environment.region": "us-east-1",
            "provisioner/local-exec.environment.role_arn": "arn:aws:iam::111111111111:role/my_role",
            "provisioner/local-exec.environment.security_configuration": "",
            "provisioner/local-exec.environment.security_group_ids": '${join(",",var.glue_endpoint_security_group_ids)}',
            "provisioner/local-exec.environment.subnet_id": "",
            "provisioner/local-exec.when": "destroy",
            "resource_type": ["null_resource"],
            "triggers.change_endpoint_name": '${md5("my_dev_endpoint")}',
            "triggers.change_extra_jars_s3_path": "${md5()}",
            "triggers.change_extra_python_libs_s3_path": "${md5()}",
            "triggers.change_number_of_nodes": '${md5("2")}',
            "triggers.change_public_keys": '${md5("${var.glue_endpoint_public_keys}")}',
            "triggers.change_region": '${md5("us-east-1")}',
            "triggers.change_role": '${md5("arn:aws:iam::111111111111:role/my_role")}',
            "triggers.change_security_configuration": "${md5()}",
            "triggers.change_security_group_ids": '${md5("${var.glue_endpoint_security_group_ids}")}',
            "triggers.change_subnet_id": "${md5()}",
        }
        block = TerraformBlock(
            name="null_resource.glue_endpoint_apply",
            config=config,
            path="test_path",
            block_type=BlockType.RESOURCE,
            attributes=nested_attributes,
        )
        attribute_key = "provisioner/local-exec.environment.security_configuration"
        block.update_inner_attribute(
            attribute_key=attribute_key, nested_attributes=nested_attributes, value_to_update=""
        )

        self.assertEqual(
            "",
            block.attributes[attribute_key],
            f"failed to update provisioner/remote-exec.inline.3, got {block.attributes[attribute_key]}",
        )

    def test_malformed_provider_block(self):
        resources_dir = os.path.join(TEST_DIRNAME, '../../resources/malformed_provider')

        graph_manager = TerraformGraphManager(db_connector=NetworkxConnector())
        graph, tf_definitions = graph_manager.build_graph_from_source_directory(resources_dir)

        expected_num_of_provider_nodes = 0
        vertices_by_block_type = graph.vertices_by_block_type
        self.assertEqual(expected_num_of_provider_nodes, len(vertices_by_block_type[BlockType.PROVIDER]))



from checkov.common.models.enums import CheckCategories
from checkov.terraform.checks.resource.base_resource_negative_value_check import BaseResourceNegativeValueCheck


class AutoScalingGroupWithPublicAccess(BaseResourceNegativeValueCheck):

    def __init__(self):
        name = "Ensure AWS Auto Scaling group launch configuration doesn't have public IP address assignment enabled"
        id = "CKV_AWS_389"
        supported_resources = ['aws_launch_configuration']
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_forbidden_values(self):
        return [True]

    def get_inspected_key(self):
        return "associate_public_ip_address"


check = AutoScalingGroupWithPublicAccess()
